@@ -48,6 +48,24 @@ class BatchRenameAction(bpy_types.PropertyGroup):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -209,6 +227,24 @@ class WM_MT_splash(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -395,6 +431,24 @@ class WM_MT_splash_about(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -581,6 +635,24 @@ class WM_MT_splash_quick_setup(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -698,6 +770,9 @@ class WM_MT_splash_quick_setup(bpy_types.Menu, bpy_types._GenericUI):
 
 
 class WM_OT_batch_rename(bpy_types.Operator):
+    bl_description = None
+    ''' '''
+
     bl_idname = None
     ''' '''
 
@@ -773,6 +848,24 @@ class WM_OT_batch_rename(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def invoke(self, context, event):
         ''' 
 
@@ -839,6 +932,12 @@ class WM_OT_batch_rename(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -934,6 +1033,24 @@ class WM_OT_context_collection_boolean_set(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -994,6 +1111,12 @@ class WM_OT_context_collection_boolean_set(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -1095,6 +1218,24 @@ class WM_OT_context_cycle_array(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1155,6 +1296,12 @@ class WM_OT_context_cycle_array(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -1256,6 +1403,24 @@ class WM_OT_context_cycle_enum(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1316,6 +1481,12 @@ class WM_OT_context_cycle_enum(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -1417,6 +1588,24 @@ class WM_OT_context_cycle_int(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1477,6 +1666,12 @@ class WM_OT_context_cycle_int(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -1578,6 +1773,24 @@ class WM_OT_context_menu_enum(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1638,6 +1851,12 @@ class WM_OT_context_menu_enum(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -1727,6 +1946,24 @@ class WM_OT_context_modal_mouse(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def invoke(self, context, event):
         ''' 
 
@@ -1799,6 +2036,12 @@ class WM_OT_context_modal_mouse(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -1894,6 +2137,24 @@ class WM_OT_context_pie_enum(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def invoke(self, context, event):
         ''' 
 
@@ -1960,6 +2221,12 @@ class WM_OT_context_pie_enum(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -2061,6 +2328,24 @@ class WM_OT_context_scale_float(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2121,6 +2406,12 @@ class WM_OT_context_scale_float(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -2222,6 +2513,24 @@ class WM_OT_context_scale_int(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2282,6 +2591,12 @@ class WM_OT_context_scale_int(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -2383,6 +2698,24 @@ class WM_OT_context_set_boolean(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2443,6 +2776,12 @@ class WM_OT_context_set_boolean(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -2544,6 +2883,24 @@ class WM_OT_context_set_enum(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2604,6 +2961,12 @@ class WM_OT_context_set_enum(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -2705,6 +3068,24 @@ class WM_OT_context_set_float(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2765,6 +3146,12 @@ class WM_OT_context_set_float(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -2860,6 +3247,24 @@ class WM_OT_context_set_id(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2920,6 +3325,12 @@ class WM_OT_context_set_id(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -3021,6 +3432,24 @@ class WM_OT_context_set_int(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3081,6 +3510,12 @@ class WM_OT_context_set_int(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -3182,6 +3617,24 @@ class WM_OT_context_set_string(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3242,6 +3695,12 @@ class WM_OT_context_set_string(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -3343,6 +3802,24 @@ class WM_OT_context_set_value(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3403,6 +3880,12 @@ class WM_OT_context_set_value(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -3504,6 +3987,24 @@ class WM_OT_context_toggle(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3564,6 +4065,12 @@ class WM_OT_context_toggle(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -3665,6 +4172,24 @@ class WM_OT_context_toggle_enum(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3725,6 +4250,12 @@ class WM_OT_context_toggle_enum(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -3817,6 +4348,24 @@ class WM_OT_doc_view(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -3877,6 +4426,12 @@ class WM_OT_doc_view(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -3969,6 +4524,24 @@ class WM_OT_doc_view_manual(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -4029,6 +4602,12 @@ class WM_OT_doc_view_manual(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -4124,6 +4703,24 @@ class WM_OT_drop_blend_file(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def invoke(self, context, _event):
         ''' 
 
@@ -4190,6 +4787,12 @@ class WM_OT_drop_blend_file(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -4282,6 +4885,24 @@ class WM_OT_operator_cheat_sheet(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -4342,6 +4963,12 @@ class WM_OT_operator_cheat_sheet(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -4437,6 +5064,24 @@ class WM_OT_operator_pie_enum(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def invoke(self, context, event):
         ''' 
 
@@ -4503,6 +5148,12 @@ class WM_OT_operator_pie_enum(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -4595,6 +5246,24 @@ class WM_OT_owner_disable(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -4655,6 +5324,12 @@ class WM_OT_owner_disable(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -4747,6 +5422,24 @@ class WM_OT_owner_enable(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -4807,6 +5500,12 @@ class WM_OT_owner_enable(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -4902,6 +5601,24 @@ class WM_OT_path_open(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -4962,6 +5679,12 @@ class WM_OT_path_open(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -5057,6 +5780,24 @@ class WM_OT_properties_add(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -5117,6 +5858,12 @@ class WM_OT_properties_add(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -5212,6 +5959,24 @@ class WM_OT_properties_context_change(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -5272,6 +6037,12 @@ class WM_OT_properties_context_change(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -5322,6 +6093,9 @@ class WM_OT_properties_edit(bpy_types.Operator):
     subtype_items = None
     ''' '''
 
+    type_items = None
+    ''' '''
+
     def as_keywords(self, ignore):
         ''' 
 
@@ -5346,7 +6120,13 @@ class WM_OT_properties_edit(bpy_types.Operator):
         '''
         pass
 
-    def check(self, _context):
+    def check(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def convert_custom_property_to_string(self, item, name):
         ''' 
 
         '''
@@ -5382,13 +6162,25 @@ class WM_OT_properties_edit(bpy_types.Operator):
         '''
         pass
 
-    def get_default_eval(self):
+    def get_property_type(self, item, property_name):
         ''' 
 
         '''
         pass
 
-    def get_value_eval(self):
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
         ''' 
 
         '''
@@ -5460,6 +6252,203 @@ class WM_OT_properties_edit(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+class WM_OT_properties_edit_value(bpy_types.Operator):
+    bl_idname = None
+    ''' '''
+
+    bl_label = None
+    ''' '''
+
+    bl_options = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def as_keywords(self, ignore):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def execute(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
+    def invoke(self, context, _event):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -5555,6 +6544,24 @@ class WM_OT_properties_remove(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -5615,6 +6622,12 @@ class WM_OT_properties_remove(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -5707,6 +6720,24 @@ class WM_OT_sysinfo(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def invoke(self, context, _event):
         ''' 
 
@@ -5773,6 +6804,12 @@ class WM_OT_sysinfo(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -5865,6 +6902,24 @@ class WM_OT_tool_set_by_id(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -5925,6 +6980,12 @@ class WM_OT_tool_set_by_id(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -6017,6 +7078,24 @@ class WM_OT_tool_set_by_index(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -6077,6 +7156,12 @@ class WM_OT_tool_set_by_index(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -6169,6 +7254,24 @@ class WM_OT_toolbar(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -6242,6 +7345,12 @@ class WM_OT_toolbar(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -6328,6 +7437,24 @@ class WM_OT_toolbar_fallback_pie(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def invoke(self, context, event):
         ''' 
 
@@ -6400,6 +7527,12 @@ class WM_OT_toolbar_fallback_pie(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -6486,6 +7619,24 @@ class WM_OT_toolbar_prompt(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def invoke(self, context, event):
         ''' 
 
@@ -6558,6 +7709,12 @@ class WM_OT_toolbar_prompt(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -6653,6 +7810,24 @@ class WM_OT_url_open(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -6713,6 +7888,12 @@ class WM_OT_url_open(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
@@ -6811,6 +7992,24 @@ class WM_OT_url_open_preset(bpy_types.Operator):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -6871,6 +8070,12 @@ class WM_OT_url_open_preset(bpy_types.Operator):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
