@@ -2,72 +2,74 @@ import sys
 import typing
 import bpy_types
 
-from . import space_info
-from . import properties_data_curve
-from . import properties_grease_pencil_common
-from . import space_console
-from . import properties_data_speaker
-from . import space_userpref
-from . import properties_data_bone
-from . import properties_physics_cloth
-from . import space_toolsystem_common
-from . import properties_render
-from . import properties_data_armature
-from . import properties_data_gpencil
-from . import properties_world
-from . import properties_physics_field
-from . import properties_constraint
-from . import properties_data_hair
-from . import properties_output
-from . import properties_physics_fluid
-from . import properties_material_gpencil
-from . import space_outliner
-from . import space_sequencer
-from . import space_graph
-from . import properties_mask_common
+from . import space_properties
+from . import properties_particle
 from . import space_node
-from . import space_view3d_toolbar
-from . import properties_collection
-from . import space_text
-from . import space_statusbar
-from . import properties_data_camera
-from . import properties_object
-from . import properties_data_light
+from . import properties_paint_common
 from . import properties_data_shaderfx
 from . import properties_material
-from . import properties_data_lattice
-from . import space_nla
-from . import properties_data_metaball
-from . import space_image
-from . import properties_texture
-from . import properties_physics_dynamicpaint
 from . import space_view3d
-from . import properties_physics_softbody
-from . import properties_data_mesh
-from . import properties_data_modifier
-from . import space_filebrowser
-from . import space_spreadsheet
-from . import properties_animviz
-from . import space_topbar
-from . import properties_data_empty
-from . import properties_scene
-from . import properties_view_layer
-from . import space_dopesheet
-from . import properties_data_volume
-from . import properties_workspace
-from . import space_toolsystem_toolbar
-from . import utils
-from . import properties_physics_rigidbody_constraint
-from . import properties_particle
-from . import properties_freestyle
-from . import properties_data_lightprobe
-from . import properties_physics_rigidbody
-from . import properties_physics_common
-from . import space_clip
-from . import properties_paint_common
 from . import properties_data_pointcloud
-from . import space_properties
+from . import properties_constraint
+from . import space_console
+from . import space_clip
+from . import properties_material_gpencil
+from . import properties_output
+from . import space_topbar
+from . import space_statusbar
+from . import space_toolsystem_common
+from . import properties_physics_field
+from . import properties_data_lightprobe
+from . import space_spreadsheet
+from . import properties_physics_rigidbody_constraint
+from . import space_dopesheet
+from . import space_userpref
+from . import properties_data_bone
+from . import properties_animviz
+from . import properties_physics_rigidbody
+from . import properties_physics_dynamicpaint
+from . import properties_data_metaball
+from . import properties_physics_softbody
+from . import properties_object
+from . import space_info
+from . import utils
+from . import properties_data_empty
+from . import space_outliner
+from . import properties_scene
+from . import properties_data_curve
+from . import properties_physics_cloth
+from . import properties_data_lattice
+from . import properties_texture
+from . import properties_data_volume
+from . import properties_mask_common
+from . import properties_workspace
+from . import properties_data_armature
+from . import properties_physics_common
+from . import properties_data_modifier
+from . import properties_data_light
+from . import space_graph
+from . import properties_grease_pencil_common
+from . import space_toolsystem_toolbar
+from . import properties_data_curves
+from . import space_nla
+from . import properties_world
+from . import space_filebrowser
+from . import properties_render
+from . import space_view3d_toolbar
+from . import properties_data_gpencil
+from . import properties_view_layer
+from . import properties_data_camera
+from . import space_sequencer
+from . import properties_physics_fluid
+from . import properties_collection
+from . import properties_data_speaker
 from . import space_time
+from . import properties_data_mesh
+from . import properties_freestyle
+from . import space_image
+from . import space_text
+
+GenericType = typing.TypeVar("GenericType")
 
 
 class UI_MT_list_item_context_menu(bpy_types.Menu, bpy_types._GenericUI):
