@@ -1081,6 +1081,14 @@ class _defs_annotate:
         pass
 
 
+class _defs_curves_sculpt:
+    def generate_from_brushes(self, context):
+        ''' 
+
+        '''
+        pass
+
+
 class _defs_edit_armature:
     bone_envelope = None
     ''' '''
@@ -1114,6 +1122,9 @@ class _defs_edit_curve:
     extrude_cursor = None
     ''' '''
 
+    pen = None
+    ''' '''
+
     tilt = None
     ''' '''
 
