@@ -1,6 +1,8 @@
 import sys
 import typing
 
+GenericType = typing.TypeVar("GenericType")
+
 
 def aspect(fontid: int, aspect: float):
     ''' Set the aspect for drawing text.
@@ -50,14 +52,14 @@ def color(fontid: int, r: float, g: float, b: float, a: float):
     pass
 
 
-def dimensions(fontid: int, text: str) -> tuple:
+def dimensions(fontid: int, text: str) -> typing.Tuple:
     ''' Return the width and height of the text.
 
     :param fontid: blf.load , for default font use 0.
     :type fontid: int
     :param text: the text to draw.
     :type text: str
-    :rtype: tuple
+    :rtype: typing.Tuple
     :return: the width and height of the text.
     '''
 
@@ -100,11 +102,11 @@ def enable(fontid: int, option: int):
     pass
 
 
-def load(filename: str):
+def load(filepath: str):
     ''' Load a new font.
 
-    :param filename: the filename of the font.
-    :type filename: str
+    :param filepath: the filepath of the font.
+    :type filepath: str
     :return: the new font's fontid or -1 if there was an error.
     '''
 
@@ -187,11 +189,11 @@ def size(fontid: int, size: float, dpi: int):
     pass
 
 
-def unload(filename: str):
+def unload(filepath: str):
     ''' Unload an existing font.
 
-    :param filename: the filename of the font.
-    :type filename: str
+    :param filepath: the filepath of the font.
+    :type filepath: str
     '''
 
     pass
