@@ -1,75 +1,79 @@
 import sys
 import typing
-from . import surface
-from . import material
-from . import dpaint
-from . import image
-from . import clip
-from . import cycles
-from . import palette
-from . import curve
-from . import info
-from . import pose
-from . import import_anim
-from . import gizmogroup
-from . import brush
-from . import paintcurve
-from . import sequencer
-from . import armature
-from . import workspace
-from . import scene
-from . import export_anim
-from . import poselib
-from . import export_scene
-from . import transform
-from . import mball
-from . import buttons
-from . import particle
-from . import cloth
-from . import ed
-from . import view2d
-from . import collection
-from . import fluid
-from . import export_mesh
-from . import world
-from . import object
-from . import spreadsheet
-from . import mask
-from . import boid
-from . import nla
-from . import marker
-from . import rigidbody
-from . import gpencil
-from . import lattice
-from . import paint
-from . import script
-from . import safe_areas
-from . import cachefile
-from . import font
-from . import console
-from . import ptcache
-from . import ui
-from . import geometry
-from . import asset
-from . import import_curve
-from . import sculpt
-from . import wm
-from . import node
-from . import text
-from . import constraint
-from . import camera
-from . import import_scene
-from . import texture
-from . import graph
-from . import render
-from . import outliner
-from . import anim
-from . import uv
 from . import view3d
+from . import import_scene
+from . import export_anim
+from . import mask
+from . import import_curve
+from . import outliner
+from . import console
+from . import ui
+from . import preferences
+from . import wm
+from . import lattice
+from . import dpaint
+from . import world
+from . import particle
+from . import gpencil
+from . import export_mesh
+from . import cloth
+from . import action
+from . import ptcache
+from . import sculpt_curves
+from . import spreadsheet
+from . import asset
+from . import surface
+from . import mesh
+from . import image
+from . import scene
+from . import palette
+from . import paintcurve
+from . import rigidbody
+from . import script
+from . import pose
+from . import cachefile
+from . import sound
+from . import boid
+from . import constraint
+from . import node
+from . import import_anim
+from . import text
+from . import graph
+from . import texture
 from . import import_mesh
 from . import file
-from . import preferences
-from . import mesh
-from . import action
-from . import sound
+from . import export_scene
+from . import marker
+from . import object
+from . import ed
+from . import workspace
+from . import fluid
+from . import camera
 from . import screen
+from . import info
+from . import paint
+from . import curve
+from . import cycles
+from . import buttons
+from . import sculpt
+from . import geometry
+from . import view2d
+from . import curves
+from . import poselib
+from . import nla
+from . import collection
+from . import anim
+from . import uv
+from . import transform
+from . import render
+from . import armature
+from . import brush
+from . import sequencer
+from . import font
+from . import mball
+from . import gizmogroup
+from . import clip
+from . import safe_areas
+from . import material
+
+GenericType = typing.TypeVar("GenericType")
