@@ -8,12 +8,12 @@ GenericType = typing.TypeVar("GenericType")
 def autocomplete(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: typing.Optional[bool] = None):
-    ''' Evaluate the namespace up until the cursor and give a list of options or complete the name if there is only one :file: `startup/bl_operators/console.py\:72 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/console.py$72>`_
+                 undo: bool = None):
+    ''' Evaluate the namespace up until the cursor and give a list of options or complete the name if there is only one :file: startup/bl_operators/console.py\:58 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/console.py$58> _
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -22,12 +22,12 @@ def autocomplete(override_context: typing.
 def banner(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: typing.Optional[bool] = None):
-    ''' Print a message when the terminal initializes :file: `startup/bl_operators/console.py\:117 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/console.py$117>`_
+           undo: bool = None):
+    ''' Print a message when the terminal initializes :file: startup/bl_operators/console.py\:103 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/console.py$103> _
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -36,19 +36,19 @@ def banner(override_context: typing.Union[typing.
 def clear(override_context: typing.Union[typing.
                                          Dict, 'bpy.types.Context'] = None,
           execution_context: typing.Union[str, int] = None,
-          undo: typing.Optional[bool] = None,
+          undo: bool = None,
           *,
-          scrollback: typing.Union[bool, typing.Any] = True,
-          history: typing.Union[bool, typing.Any] = False):
+          scrollback: bool = True,
+          history: bool = False):
     ''' Clear text by type
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param scrollback: Scrollback, Clear the scrollback history
-    :type scrollback: typing.Union[bool, typing.Any]
+    :type scrollback: bool
     :param history: History, Clear the command history
-    :type history: typing.Union[bool, typing.Any]
+    :type history: bool
     '''
 
     pass
@@ -57,12 +57,12 @@ def clear(override_context: typing.Union[typing.
 def clear_line(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: typing.Optional[bool] = None):
+               undo: bool = None):
     ''' Clear the line and store in history
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -71,12 +71,12 @@ def clear_line(override_context: typing.
 def copy(override_context: typing.Union[typing.
                                         Dict, 'bpy.types.Context'] = None,
          execution_context: typing.Union[str, int] = None,
-         undo: typing.Optional[bool] = None):
+         undo: bool = None):
     ''' Copy selected text to clipboard
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -85,12 +85,12 @@ def copy(override_context: typing.Union[typing.
 def copy_as_script(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: typing.Optional[bool] = None):
-    ''' Copy the console contents for use in a script :file: `startup/bl_operators/console.py\:94 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/console.py$94>`_
+                   undo: bool = None):
+    ''' Copy the console contents for use in a script :file: startup/bl_operators/console.py\:80 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/console.py$80> _
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -99,16 +99,16 @@ def copy_as_script(override_context: typing.
 def delete(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: typing.Optional[bool] = None,
+           undo: bool = None,
            *,
-           type: typing.Optional[typing.Any] = 'NEXT_CHARACTER'):
+           type: typing.Union[str, int] = 'NEXT_CHARACTER'):
     ''' Delete text by cursor position
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param type: Type, Which part of the text to delete
-    :type type: typing.Optional[typing.Any]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -117,16 +117,16 @@ def delete(override_context: typing.Union[typing.
 def execute(override_context: typing.Union[typing.
                                            Dict, 'bpy.types.Context'] = None,
             execution_context: typing.Union[str, int] = None,
-            undo: typing.Optional[bool] = None,
+            undo: bool = None,
             *,
-            interactive: typing.Union[bool, typing.Any] = False):
+            interactive: bool = False):
     ''' Execute the current console line as a python expression
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param interactive: interactive
-    :type interactive: typing.Union[bool, typing.Any]
+    :type interactive: bool
     '''
 
     pass
@@ -135,22 +135,22 @@ def execute(override_context: typing.Union[typing.
 def history_append(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: typing.Optional[bool] = None,
+                   undo: bool = None,
                    *,
-                   text: typing.Union[str, typing.Any] = "",
-                   current_character: typing.Optional[typing.Any] = 0,
-                   remove_duplicates: typing.Union[bool, typing.Any] = False):
+                   text: str = "",
+                   current_character: int = 0,
+                   remove_duplicates: bool = False):
     ''' Append history at cursor position
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param text: Text, Text to insert at the cursor position
-    :type text: typing.Union[str, typing.Any]
+    :type text: str
     :param current_character: Cursor, The index of the cursor
-    :type current_character: typing.Optional[typing.Any]
+    :type current_character: int
     :param remove_duplicates: Remove Duplicates, Remove duplicate items in the history
-    :type remove_duplicates: typing.Union[bool, typing.Any]
+    :type remove_duplicates: bool
     '''
 
     pass
@@ -159,16 +159,16 @@ def history_append(override_context: typing.
 def history_cycle(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: typing.Optional[bool] = None,
+                  undo: bool = None,
                   *,
-                  reverse: typing.Union[bool, typing.Any] = False):
+                  reverse: bool = False):
     ''' Cycle through history
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param reverse: Reverse, Reverse cycle history
-    :type reverse: typing.Union[bool, typing.Any]
+    :type reverse: bool
     '''
 
     pass
@@ -177,12 +177,12 @@ def history_cycle(override_context: typing.
 def indent(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: typing.Optional[bool] = None):
+           undo: bool = None):
     ''' Add 4 spaces at line beginning
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -191,12 +191,12 @@ def indent(override_context: typing.Union[typing.
 def indent_or_autocomplete(override_context: typing.
                            Union[typing.Dict, 'bpy.types.Context'] = None,
                            execution_context: typing.Union[str, int] = None,
-                           undo: typing.Optional[bool] = None):
+                           undo: bool = None):
     ''' Indent selected text or autocomplete
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -205,16 +205,16 @@ def indent_or_autocomplete(override_context: typing.
 def insert(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: typing.Optional[bool] = None,
+           undo: bool = None,
            *,
-           text: typing.Union[str, typing.Any] = ""):
+           text: str = ""):
     ''' Insert text at cursor position
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param text: Text, Text to insert at the cursor position
-    :type text: typing.Union[str, typing.Any]
+    :type text: str
     '''
 
     pass
@@ -223,16 +223,16 @@ def insert(override_context: typing.Union[typing.
 def language(override_context: typing.Union[typing.
                                             Dict, 'bpy.types.Context'] = None,
              execution_context: typing.Union[str, int] = None,
-             undo: typing.Optional[bool] = None,
+             undo: bool = None,
              *,
-             language: typing.Union[str, typing.Any] = ""):
+             language: str = ""):
     ''' Set the current language for this console
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param language: Language
-    :type language: typing.Union[str, typing.Any]
+    :type language: str
     '''
 
     pass
@@ -241,16 +241,16 @@ def language(override_context: typing.Union[typing.
 def move(override_context: typing.Union[typing.
                                         Dict, 'bpy.types.Context'] = None,
          execution_context: typing.Union[str, int] = None,
-         undo: typing.Optional[bool] = None,
+         undo: bool = None,
          *,
-         type: typing.Optional[typing.Any] = 'LINE_BEGIN'):
+         type: typing.Union[str, int] = 'LINE_BEGIN'):
     ''' Move cursor position
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param type: Type, Where to move cursor to
-    :type type: typing.Optional[typing.Any]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -259,12 +259,12 @@ def move(override_context: typing.Union[typing.
 def paste(override_context: typing.Union[typing.
                                          Dict, 'bpy.types.Context'] = None,
           execution_context: typing.Union[str, int] = None,
-          undo: typing.Optional[bool] = None):
+          undo: bool = None):
     ''' Paste text from clipboard
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -273,19 +273,19 @@ def paste(override_context: typing.Union[typing.
 def scrollback_append(override_context: typing.
                       Union[typing.Dict, 'bpy.types.Context'] = None,
                       execution_context: typing.Union[str, int] = None,
-                      undo: typing.Optional[bool] = None,
+                      undo: bool = None,
                       *,
-                      text: typing.Union[str, typing.Any] = "",
-                      type: typing.Optional[typing.Any] = 'OUTPUT'):
+                      text: str = "",
+                      type: typing.Union[str, int] = 'OUTPUT'):
     ''' Append scrollback text by type
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param text: Text, Text to insert at the cursor position
-    :type text: typing.Union[str, typing.Any]
+    :type text: str
     :param type: Type, Console output type
-    :type type: typing.Optional[typing.Any]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -294,12 +294,12 @@ def scrollback_append(override_context: typing.
 def select_set(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: typing.Optional[bool] = None):
+               undo: bool = None):
     ''' Set the console selection
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -308,12 +308,12 @@ def select_set(override_context: typing.
 def select_word(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: typing.Optional[bool] = None):
+                undo: bool = None):
     ''' Select word at cursor position
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -322,12 +322,12 @@ def select_word(override_context: typing.
 def unindent(override_context: typing.Union[typing.
                                             Dict, 'bpy.types.Context'] = None,
              execution_context: typing.Union[str, int] = None,
-             undo: typing.Optional[bool] = None):
+             undo: bool = None):
     ''' Delete 4 spaces from line beginning
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
