@@ -1,8 +1,16 @@
 import sys
 import typing
+import bpy.types
+
+GenericType = typing.TypeVar("GenericType")
 
 
-def bvh(filepath: str = "",
+def bvh(override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        filepath: str = "",
         check_existing: bool = True,
         filter_glob: str = "*.bvh",
         global_scale: float = 1.0,
@@ -12,6 +20,9 @@ def bvh(filepath: str = "",
         root_transform_only: bool = False):
     ''' Save a BVH motion capture file from an armature
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Filepath used for exporting the file
     :type filepath: str
     :param check_existing: Check Existing, Check and warn on overwriting existing files
