@@ -1,11 +1,20 @@
 import sys
 import typing
+import bpy.types
+
+GenericType = typing.TypeVar("GenericType")
 
 
-def fbx(filepath: str = "",
+def fbx(override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        filepath: str = "",
         check_existing: bool = True,
         filter_glob: str = "*.fbx",
         use_selection: bool = False,
+        use_visible: bool = False,
         use_active_collection: bool = False,
         global_scale: float = 1.0,
         apply_unit_scale: bool = True,
@@ -21,6 +30,7 @@ def fbx(filepath: str = "",
         use_subsurf: bool = False,
         use_mesh_edges: bool = False,
         use_tspace: bool = False,
+        use_triangles: bool = False,
         use_custom_props: bool = False,
         add_leaf_bones: bool = True,
         primary_bone_axis: typing.Union[str, int] = 'Y',
@@ -43,6 +53,9 @@ def fbx(filepath: str = "",
         axis_up: typing.Union[str, int] = 'Y'):
     ''' Write a FBX file
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Filepath used for exporting the file
     :type filepath: str
     :param check_existing: Check Existing, Check and warn on overwriting existing files
@@ -51,6 +64,8 @@ def fbx(filepath: str = "",
     :type filter_glob: str
     :param use_selection: Selected Objects, Export selected and visible objects only
     :type use_selection: bool
+    :param use_visible: Visible Objects, Export visible objects only
+    :type use_visible: bool
     :param use_active_collection: Active Collection, Export only objects from the active collection (and its children)
     :type use_active_collection: bool
     :param global_scale: Scale, Scale all data (Some importers do not support scaled armatures!)
@@ -77,6 +92,8 @@ def fbx(filepath: str = "",
     :type use_mesh_edges: bool
     :param use_tspace: Tangent Space, Add binormal and tangent vectors, together with normal they form the tangent space (will only work correctly with tris/quads only meshes!)
     :type use_tspace: bool
+    :param use_triangles: Triangulate Faces, Convert all faces to triangles
+    :type use_triangles: bool
     :param use_custom_props: Custom Properties, Export custom properties
     :type use_custom_props: bool
     :param add_leaf_bones: Add Leaf Bones, Append a final bone to the end of each chain to specify last bone length (use this when you intend to edit the armature from exported data)
@@ -122,7 +139,12 @@ def fbx(filepath: str = "",
     pass
 
 
-def gltf(filepath: str = "",
+def gltf(override_context: typing.Union[typing.
+                                        Dict, 'bpy.types.Context'] = None,
+         execution_context: typing.Union[str, int] = None,
+         undo: bool = None,
+         *,
+         filepath: str = "",
          check_existing: bool = True,
          export_format: typing.Union[str, int] = 'GLB',
          ui_tab: typing.Union[str, int] = 'GENERAL',
@@ -145,11 +167,11 @@ def gltf(filepath: str = "",
          use_mesh_edges: bool = False,
          use_mesh_vertices: bool = False,
          export_cameras: bool = False,
-         export_selected: bool = False,
          use_selection: bool = False,
          use_visible: bool = False,
          use_renderable: bool = False,
          use_active_collection: bool = False,
+         use_active_scene: bool = False,
          export_extras: bool = False,
          export_yup: bool = True,
          export_apply: bool = False,
@@ -159,7 +181,7 @@ def gltf(filepath: str = "",
          export_force_sampling: bool = True,
          export_nla_strips: bool = True,
          export_def_bones: bool = False,
-         optimize_animation_size: bool = True,
+         optimize_animation_size: bool = False,
          export_current_frame: bool = False,
          export_skins: bool = True,
          export_all_influences: bool = False,
@@ -172,6 +194,9 @@ def gltf(filepath: str = "",
          filter_glob: str = "*.glb;*.gltf"):
     ''' Export scene as glTF 2.0 file
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Filepath used for exporting the file
     :type filepath: str
     :param check_existing: Check Existing, Check and warn on overwriting existing files
@@ -218,8 +243,6 @@ def gltf(filepath: str = "",
     :type use_mesh_vertices: bool
     :param export_cameras: Cameras, Export cameras
     :type export_cameras: bool
-    :param export_selected: Selected Objects, Export selected objects only
-    :type export_selected: bool
     :param use_selection: Selected Objects, Export selected objects only
     :type use_selection: bool
     :param use_visible: Visible Objects, Export visible objects only
@@ -228,6 +251,8 @@ def gltf(filepath: str = "",
     :type use_renderable: bool
     :param use_active_collection: Active Collection, Export objects in the active collection only
     :type use_active_collection: bool
+    :param use_active_scene: Active Scene, Export active scene only
+    :type use_active_scene: bool
     :param export_extras: Custom Properties, Export custom properties as glTF extras
     :type export_extras: bool
     :param export_yup: +Y Up, Export using glTF convention, +Y up
@@ -246,7 +271,7 @@ def gltf(filepath: str = "",
     :type export_nla_strips: bool
     :param export_def_bones: Export Deformation Bones Only, Export Deformation bones only (and needed bones for hierarchy)
     :type export_def_bones: bool
-    :param optimize_animation_size: Optimize Animation Size, Reduces exported filesize by removing duplicate keyframesCan cause problems with stepped animation
+    :param optimize_animation_size: Optimize Animation Size, Reduce exported file-size by removing duplicate keyframes(can cause problems with stepped animation)
     :type optimize_animation_size: bool
     :param export_current_frame: Use Current Frame, Export the scene in the current animation frame
     :type export_current_frame: bool
@@ -273,7 +298,12 @@ def gltf(filepath: str = "",
     pass
 
 
-def obj(filepath: str = "",
+def obj(override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        filepath: str = "",
         check_existing: bool = True,
         filter_glob: str = "*.obj;*.mtl",
         use_selection: bool = False,
@@ -298,6 +328,9 @@ def obj(filepath: str = "",
         axis_up: typing.Union[str, int] = 'Y'):
     ''' Save a Wavefront OBJ File
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Filepath used for exporting the file
     :type filepath: str
     :param check_existing: Check Existing, Check and warn on overwriting existing files
@@ -349,7 +382,12 @@ def obj(filepath: str = "",
     pass
 
 
-def x3d(filepath: str = "",
+def x3d(override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        filepath: str = "",
         check_existing: bool = True,
         filter_glob: str = "*.x3d",
         use_selection: bool = False,
@@ -366,6 +404,9 @@ def x3d(filepath: str = "",
         axis_up: typing.Union[str, int] = 'Y'):
     ''' Export selection to Extensible 3D file (.x3d)
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Filepath used for exporting the file
     :type filepath: str
     :param check_existing: Check Existing, Check and warn on overwriting existing files
