@@ -13,7 +13,8 @@ def gizmo_select(override_context: typing.
                  extend: bool = False,
                  deselect: bool = False,
                  toggle: bool = False,
-                 deselect_all: bool = False):
+                 deselect_all: bool = False,
+                 select_passthrough: bool = False):
     ''' Select the currently highlighted gizmo
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
@@ -27,6 +28,8 @@ def gizmo_select(override_context: typing.
     :type toggle: bool
     :param deselect_all: Deselect On Nothing, Deselect all when nothing under the cursor
     :type deselect_all: bool
+    :param select_passthrough: Only Select Unselected, Ignore the select action when the element is already selected
+    :type select_passthrough: bool
     '''
 
     pass
