@@ -1,24 +1,28 @@
 import sys
 import typing
 import bpy.types
+import mathutils
 import bpy.ops.transform
 
 GenericType = typing.TypeVar("GenericType")
 
 
-def add_feather_vertex(override_context: typing.
-                       Union[typing.Dict, 'bpy.types.Context'] = None,
-                       execution_context: typing.Union[str, int] = None,
-                       undo: typing.Optional[bool] = None,
-                       *,
-                       location: typing.Optional[typing.Any] = (0.0, 0.0)):
+def add_feather_vertex(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        location: typing.Union[typing.List[float], typing.
+                               Tuple[float, float], 'mathutils.Vector'] = (
+                                   0.0, 0.0)):
     ''' Add vertex to feather
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param location: Location, Location of vertex in normalized space
-    :type location: typing.Optional[typing.Any]
+    :type location: typing.Union[typing.List[float], typing.Tuple[float, float], 'mathutils.Vector']
     '''
 
     pass
@@ -28,60 +32,61 @@ def add_feather_vertex_slide(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
+        undo: bool = None,
         *,
-        MASK_OT_add_feather_vertex: typing.
-        Optional['add_feather_vertex'] = None,
-        MASK_OT_slide_point: typing.Optional['slide_point'] = None):
+        MASK_OT_add_feather_vertex: 'add_feather_vertex' = None,
+        MASK_OT_slide_point: 'slide_point' = None):
     ''' Add new vertex to feather and slide it
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param MASK_OT_add_feather_vertex: Add Feather Vertex, Add vertex to feather
-    :type MASK_OT_add_feather_vertex: typing.Optional['add_feather_vertex']
+    :type MASK_OT_add_feather_vertex: 'add_feather_vertex'
     :param MASK_OT_slide_point: Slide Point, Slide control points
-    :type MASK_OT_slide_point: typing.Optional['slide_point']
+    :type MASK_OT_slide_point: 'slide_point'
     '''
 
     pass
 
 
-def add_vertex(override_context: typing.
-               Union[typing.Dict, 'bpy.types.Context'] = None,
-               execution_context: typing.Union[str, int] = None,
-               undo: typing.Optional[bool] = None,
-               *,
-               location: typing.Optional[typing.Any] = (0.0, 0.0)):
+def add_vertex(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        location: typing.Union[typing.List[float], typing.
+                               Tuple[float, float], 'mathutils.Vector'] = (
+                                   0.0, 0.0)):
     ''' Add vertex to active spline
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param location: Location, Location of vertex in normalized space
-    :type location: typing.Optional[typing.Any]
+    :type location: typing.Union[typing.List[float], typing.Tuple[float, float], 'mathutils.Vector']
     '''
 
     pass
 
 
-def add_vertex_slide(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
-        *,
-        MASK_OT_add_vertex: typing.Optional['add_vertex'] = None,
-        MASK_OT_slide_point: typing.Optional['slide_point'] = None):
+def add_vertex_slide(override_context: typing.
+                     Union[typing.Dict, 'bpy.types.Context'] = None,
+                     execution_context: typing.Union[str, int] = None,
+                     undo: bool = None,
+                     *,
+                     MASK_OT_add_vertex: 'add_vertex' = None,
+                     MASK_OT_slide_point: 'slide_point' = None):
     ''' Add new vertex and slide it
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param MASK_OT_add_vertex: Add Vertex, Add vertex to active spline
-    :type MASK_OT_add_vertex: typing.Optional['add_vertex']
+    :type MASK_OT_add_vertex: 'add_vertex'
     :param MASK_OT_slide_point: Slide Point, Slide control points
-    :type MASK_OT_slide_point: typing.Optional['slide_point']
+    :type MASK_OT_slide_point: 'slide_point'
     '''
 
     pass
@@ -90,12 +95,12 @@ def add_vertex_slide(
 def copy_splines(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: typing.Optional[bool] = None):
+                 undo: bool = None):
     ''' Copy selected splines to clipboard
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -104,12 +109,12 @@ def copy_splines(override_context: typing.
 def cyclic_toggle(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: typing.Optional[bool] = None):
+                  undo: bool = None):
     ''' Toggle cyclic for selected splines
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -118,12 +123,12 @@ def cyclic_toggle(override_context: typing.
 def delete(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: typing.Optional[bool] = None):
+           undo: bool = None):
     ''' Delete selected control points or splines
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -132,34 +137,34 @@ def delete(override_context: typing.Union[typing.
 def duplicate(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: typing.Optional[bool] = None):
+              undo: bool = None):
     ''' Duplicate selected control points and segments between them
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
 
 
-def duplicate_move(override_context: typing.
-                   Union[typing.Dict, 'bpy.types.Context'] = None,
-                   execution_context: typing.Union[str, int] = None,
-                   undo: typing.Optional[bool] = None,
-                   *,
-                   MASK_OT_duplicate: typing.Optional['duplicate'] = None,
-                   TRANSFORM_OT_translate: typing.
-                   Optional['bpy.ops.transform.translate'] = None):
+def duplicate_move(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        MASK_OT_duplicate: 'duplicate' = None,
+        TRANSFORM_OT_translate: 'bpy.ops.transform.translate' = None):
     ''' Duplicate mask and move
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param MASK_OT_duplicate: Duplicate Mask, Duplicate selected control points and segments between them
-    :type MASK_OT_duplicate: typing.Optional['duplicate']
+    :type MASK_OT_duplicate: 'duplicate'
     :param TRANSFORM_OT_translate: Move, Move selected items
-    :type TRANSFORM_OT_translate: typing.Optional['bpy.ops.transform.translate']
+    :type TRANSFORM_OT_translate: 'bpy.ops.transform.translate'
     '''
 
     pass
@@ -168,12 +173,12 @@ def duplicate_move(override_context: typing.
 def feather_weight_clear(override_context: typing.
                          Union[typing.Dict, 'bpy.types.Context'] = None,
                          execution_context: typing.Union[str, int] = None,
-                         undo: typing.Optional[bool] = None):
+                         undo: bool = None):
     ''' Reset the feather weight to zero
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -182,16 +187,16 @@ def feather_weight_clear(override_context: typing.
 def handle_type_set(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: typing.Optional[bool] = None,
+                    undo: bool = None,
                     *,
-                    type: typing.Optional[typing.Any] = 'AUTO'):
+                    type: typing.Union[str, int] = 'AUTO'):
     ''' Set type of handles for selected control points
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param type: Type, Spline type
-    :type type: typing.Optional[typing.Any]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -200,16 +205,16 @@ def handle_type_set(override_context: typing.
 def hide_view_clear(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: typing.Optional[bool] = None,
+                    undo: bool = None,
                     *,
-                    select: typing.Union[bool, typing.Any] = True):
+                    select: bool = True):
     ''' Reveal the layer by setting the hide flag
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param select: Select
-    :type select: typing.Union[bool, typing.Any]
+    :type select: bool
     '''
 
     pass
@@ -218,16 +223,16 @@ def hide_view_clear(override_context: typing.
 def hide_view_set(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: typing.Optional[bool] = None,
+                  undo: bool = None,
                   *,
-                  unselected: typing.Union[bool, typing.Any] = False):
+                  unselected: bool = False):
     ''' Hide the layer by setting the hide flag
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param unselected: Unselected, Hide unselected rather than selected layers
-    :type unselected: typing.Union[bool, typing.Any]
+    :type unselected: bool
     '''
 
     pass
@@ -236,16 +241,16 @@ def hide_view_set(override_context: typing.
 def layer_move(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: typing.Optional[bool] = None,
+               undo: bool = None,
                *,
-               direction: typing.Optional[typing.Any] = 'UP'):
+               direction: typing.Union[str, int] = 'UP'):
     ''' Move the active layer up/down in the list
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param direction: Direction, Direction to move the active layer
-    :type direction: typing.Optional[typing.Any]
+    :type direction: typing.Union[str, int]
     '''
 
     pass
@@ -254,16 +259,16 @@ def layer_move(override_context: typing.
 def layer_new(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: typing.Optional[bool] = None,
+              undo: bool = None,
               *,
-              name: typing.Union[str, typing.Any] = ""):
+              name: str = ""):
     ''' Add new mask layer for masking
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param name: Name, Name of new mask layer
-    :type name: typing.Union[str, typing.Any]
+    :type name: str
     '''
 
     pass
@@ -272,12 +277,12 @@ def layer_new(override_context: typing.Union[typing.
 def layer_remove(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: typing.Optional[bool] = None):
+                 undo: bool = None):
     ''' Remove mask layer
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -286,16 +291,16 @@ def layer_remove(override_context: typing.
 def new(override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
+        undo: bool = None,
         *,
-        name: typing.Union[str, typing.Any] = ""):
+        name: str = ""):
     ''' Create new mask
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param name: Name, Name of new mask
-    :type name: typing.Union[str, typing.Any]
+    :type name: str
     '''
 
     pass
@@ -304,12 +309,12 @@ def new(override_context: typing.Union[typing.
 def normals_make_consistent(override_context: typing.
                             Union[typing.Dict, 'bpy.types.Context'] = None,
                             execution_context: typing.Union[str, int] = None,
-                            undo: typing.Optional[bool] = None):
+                            undo: bool = None):
     ''' Recalculate the direction of selected handles
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -318,12 +323,12 @@ def normals_make_consistent(override_context: typing.
 def parent_clear(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: typing.Optional[bool] = None):
+                 undo: bool = None):
     ''' Clear the mask's parenting
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -332,12 +337,12 @@ def parent_clear(override_context: typing.
 def parent_set(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: typing.Optional[bool] = None):
+               undo: bool = None):
     ''' Set the mask's parenting
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -346,54 +351,60 @@ def parent_set(override_context: typing.
 def paste_splines(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: typing.Optional[bool] = None):
+                  undo: bool = None):
     ''' Paste splines from clipboard
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
 
 
-def primitive_circle_add(override_context: typing.
-                         Union[typing.Dict, 'bpy.types.Context'] = None,
-                         execution_context: typing.Union[str, int] = None,
-                         undo: typing.Optional[bool] = None,
-                         *,
-                         size: typing.Optional[typing.Any] = 100.0,
-                         location: typing.Optional[typing.Any] = (0.0, 0.0)):
+def primitive_circle_add(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        size: float = 100.0,
+        location: typing.Union[typing.List[float], typing.
+                               Tuple[float, float], 'mathutils.Vector'] = (
+                                   0.0, 0.0)):
     ''' Add new circle-shaped spline
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param size: Size, Size of new circle
-    :type size: typing.Optional[typing.Any]
+    :type size: float
     :param location: Location, Location of new circle
-    :type location: typing.Optional[typing.Any]
+    :type location: typing.Union[typing.List[float], typing.Tuple[float, float], 'mathutils.Vector']
     '''
 
     pass
 
 
-def primitive_square_add(override_context: typing.
-                         Union[typing.Dict, 'bpy.types.Context'] = None,
-                         execution_context: typing.Union[str, int] = None,
-                         undo: typing.Optional[bool] = None,
-                         *,
-                         size: typing.Optional[typing.Any] = 100.0,
-                         location: typing.Optional[typing.Any] = (0.0, 0.0)):
+def primitive_square_add(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        size: float = 100.0,
+        location: typing.Union[typing.List[float], typing.
+                               Tuple[float, float], 'mathutils.Vector'] = (
+                                   0.0, 0.0)):
     ''' Add new square-shaped spline
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param size: Size, Size of new circle
-    :type size: typing.Optional[typing.Any]
+    :type size: float
     :param location: Location, Location of new circle
-    :type location: typing.Optional[typing.Any]
+    :type location: typing.Union[typing.List[float], typing.Tuple[float, float], 'mathutils.Vector']
     '''
 
     pass
@@ -402,28 +413,33 @@ def primitive_square_add(override_context: typing.
 def select(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: typing.Optional[bool] = None,
+           undo: bool = None,
            *,
-           extend: typing.Union[bool, typing.Any] = False,
-           deselect: typing.Union[bool, typing.Any] = False,
-           toggle: typing.Union[bool, typing.Any] = False,
-           deselect_all: typing.Union[bool, typing.Any] = False,
-           location: typing.Optional[typing.Any] = (0.0, 0.0)):
+           extend: bool = False,
+           deselect: bool = False,
+           toggle: bool = False,
+           deselect_all: bool = False,
+           select_passthrough: bool = False,
+           location: typing.Union[typing.List[float], typing.
+                                  Tuple[float, float], 'mathutils.Vector'] = (
+                                      0.0, 0.0)):
     ''' Select spline points
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param extend: Extend, Extend selection instead of deselecting everything first
-    :type extend: typing.Union[bool, typing.Any]
+    :type extend: bool
     :param deselect: Deselect, Remove from selection
-    :type deselect: typing.Union[bool, typing.Any]
+    :type deselect: bool
     :param toggle: Toggle Selection, Toggle the selection
-    :type toggle: typing.Union[bool, typing.Any]
+    :type toggle: bool
     :param deselect_all: Deselect On Nothing, Deselect all when nothing under the cursor
-    :type deselect_all: typing.Union[bool, typing.Any]
+    :type deselect_all: bool
+    :param select_passthrough: Only Select Unselected, Ignore the select action when the element is already selected
+    :type select_passthrough: bool
     :param location: Location, Location of vertex in normalized space
-    :type location: typing.Optional[typing.Any]
+    :type location: typing.Union[typing.List[float], typing.Tuple[float, float], 'mathutils.Vector']
     '''
 
     pass
@@ -432,16 +448,16 @@ def select(override_context: typing.Union[typing.
 def select_all(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: typing.Optional[bool] = None,
+               undo: bool = None,
                *,
-               action: typing.Optional[typing.Any] = 'TOGGLE'):
+               action: typing.Union[str, int] = 'TOGGLE'):
     ''' Change selection of all curve points
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
-    :param action: Action, Selection action to execute * ``TOGGLE`` Toggle -- Toggle selection for all elements. * ``SELECT`` Select -- Select all elements. * ``DESELECT`` Deselect -- Deselect all elements. * ``INVERT`` Invert -- Invert selection of all elements.
-    :type action: typing.Optional[typing.Any]
+    :type undo: bool
+    :param action: Action, Selection action to execute * TOGGLE Toggle -- Toggle selection for all elements. * SELECT Select -- Select all elements. * DESELECT Deselect -- Deselect all elements. * INVERT Invert -- Invert selection of all elements.
+    :type action: typing.Union[str, int]
     '''
 
     pass
@@ -450,31 +466,31 @@ def select_all(override_context: typing.
 def select_box(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: typing.Optional[bool] = None,
+               undo: bool = None,
                *,
-               xmin: typing.Optional[typing.Any] = 0,
-               xmax: typing.Optional[typing.Any] = 0,
-               ymin: typing.Optional[typing.Any] = 0,
-               ymax: typing.Optional[typing.Any] = 0,
-               wait_for_input: typing.Union[bool, typing.Any] = True,
-               mode: typing.Optional[typing.Any] = 'SET'):
+               xmin: int = 0,
+               xmax: int = 0,
+               ymin: int = 0,
+               ymax: int = 0,
+               wait_for_input: bool = True,
+               mode: typing.Union[str, int] = 'SET'):
     ''' Select curve points using box selection
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param xmin: X Min
-    :type xmin: typing.Optional[typing.Any]
+    :type xmin: int
     :param xmax: X Max
-    :type xmax: typing.Optional[typing.Any]
+    :type xmax: int
     :param ymin: Y Min
-    :type ymin: typing.Optional[typing.Any]
+    :type ymin: int
     :param ymax: Y Max
-    :type ymax: typing.Optional[typing.Any]
+    :type ymax: int
     :param wait_for_input: Wait for Input
-    :type wait_for_input: typing.Union[bool, typing.Any]
-    :param mode: Mode * ``SET`` Set -- Set a new selection. * ``ADD`` Extend -- Extend existing selection. * ``SUB`` Subtract -- Subtract existing selection.
-    :type mode: typing.Optional[typing.Any]
+    :type wait_for_input: bool
+    :param mode: Mode * SET Set -- Set a new selection. * ADD Extend -- Extend existing selection. * SUB Subtract -- Subtract existing selection.
+    :type mode: typing.Union[str, int]
     '''
 
     pass
@@ -483,28 +499,28 @@ def select_box(override_context: typing.
 def select_circle(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: typing.Optional[bool] = None,
+                  undo: bool = None,
                   *,
-                  x: typing.Optional[typing.Any] = 0,
-                  y: typing.Optional[typing.Any] = 0,
-                  radius: typing.Optional[typing.Any] = 25,
-                  wait_for_input: typing.Union[bool, typing.Any] = True,
-                  mode: typing.Optional[typing.Any] = 'SET'):
+                  x: int = 0,
+                  y: int = 0,
+                  radius: int = 25,
+                  wait_for_input: bool = True,
+                  mode: typing.Union[str, int] = 'SET'):
     ''' Select curve points using circle selection
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param x: X
-    :type x: typing.Optional[typing.Any]
+    :type x: int
     :param y: Y
-    :type y: typing.Optional[typing.Any]
+    :type y: int
     :param radius: Radius
-    :type radius: typing.Optional[typing.Any]
+    :type radius: int
     :param wait_for_input: Wait for Input
-    :type wait_for_input: typing.Union[bool, typing.Any]
-    :param mode: Mode * ``SET`` Set -- Set a new selection. * ``ADD`` Extend -- Extend existing selection. * ``SUB`` Subtract -- Subtract existing selection.
-    :type mode: typing.Optional[typing.Any]
+    :type wait_for_input: bool
+    :param mode: Mode * SET Set -- Set a new selection. * ADD Extend -- Extend existing selection. * SUB Subtract -- Subtract existing selection.
+    :type mode: typing.Union[str, int]
     '''
 
     pass
@@ -513,20 +529,20 @@ def select_circle(override_context: typing.
 def select_lasso(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: typing.Optional[bool] = None,
+                 undo: bool = None,
                  *,
-                 path: typing.Optional[bpy.types.bpy_prop_collection[
-                     'bpy.types.OperatorMousePath']] = None,
-                 mode: typing.Optional[typing.Any] = 'SET'):
+                 path: bpy.types.
+                 bpy_prop_collection['bpy.types.OperatorMousePath'] = None,
+                 mode: typing.Union[str, int] = 'SET'):
     ''' Select curve points using lasso selection
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param path: Path
-    :type path: typing.Optional[bpy.types.bpy_prop_collection['bpy.types.OperatorMousePath']]
-    :param mode: Mode * ``SET`` Set -- Set a new selection. * ``ADD`` Extend -- Extend existing selection. * ``SUB`` Subtract -- Subtract existing selection.
-    :type mode: typing.Optional[typing.Any]
+    :type path: bpy.types.bpy_prop_collection['bpy.types.OperatorMousePath']
+    :param mode: Mode * SET Set -- Set a new selection. * ADD Extend -- Extend existing selection. * SUB Subtract -- Subtract existing selection.
+    :type mode: typing.Union[str, int]
     '''
 
     pass
@@ -535,12 +551,12 @@ def select_lasso(override_context: typing.
 def select_less(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: typing.Optional[bool] = None):
+                undo: bool = None):
     ''' Deselect spline points at the boundary of each selection region
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -549,12 +565,12 @@ def select_less(override_context: typing.
 def select_linked(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: typing.Optional[bool] = None):
+                  undo: bool = None):
     ''' Select all curve points linked to already selected ones
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -563,16 +579,16 @@ def select_linked(override_context: typing.
 def select_linked_pick(override_context: typing.
                        Union[typing.Dict, 'bpy.types.Context'] = None,
                        execution_context: typing.Union[str, int] = None,
-                       undo: typing.Optional[bool] = None,
+                       undo: bool = None,
                        *,
-                       deselect: typing.Union[bool, typing.Any] = False):
+                       deselect: bool = False):
     ''' (De)select all points linked to the curve under the mouse cursor
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param deselect: Deselect
-    :type deselect: typing.Union[bool, typing.Any]
+    :type deselect: bool
     '''
 
     pass
@@ -581,12 +597,12 @@ def select_linked_pick(override_context: typing.
 def select_more(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: typing.Optional[bool] = None):
+                undo: bool = None):
     ''' Select more spline points connected to initial selection
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -595,12 +611,12 @@ def select_more(override_context: typing.
 def shape_key_clear(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: typing.Optional[bool] = None):
+                    undo: bool = None):
     ''' Remove mask shape keyframe for active mask layer at the current frame
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -609,12 +625,12 @@ def shape_key_clear(override_context: typing.
 def shape_key_feather_reset(override_context: typing.
                             Union[typing.Dict, 'bpy.types.Context'] = None,
                             execution_context: typing.Union[str, int] = None,
-                            undo: typing.Optional[bool] = None):
+                            undo: bool = None):
     ''' Reset feather weights on all selected points animation values
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -623,12 +639,12 @@ def shape_key_feather_reset(override_context: typing.
 def shape_key_insert(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: typing.Optional[bool] = None):
+                     undo: bool = None):
     ''' Insert mask shape keyframe for active mask layer at the current frame
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -637,19 +653,19 @@ def shape_key_insert(override_context: typing.
 def shape_key_rekey(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: typing.Optional[bool] = None,
+                    undo: bool = None,
                     *,
-                    location: typing.Union[bool, typing.Any] = True,
-                    feather: typing.Union[bool, typing.Any] = True):
+                    location: bool = True,
+                    feather: bool = True):
     ''' Recalculate animation data on selected points for frames selected in the dopesheet
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param location: Location
-    :type location: typing.Union[bool, typing.Any]
+    :type location: bool
     :param feather: Feather
-    :type feather: typing.Union[bool, typing.Any]
+    :type feather: bool
     '''
 
     pass
@@ -658,19 +674,19 @@ def shape_key_rekey(override_context: typing.
 def slide_point(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: typing.Optional[bool] = None,
+                undo: bool = None,
                 *,
-                slide_feather: typing.Union[bool, typing.Any] = False,
-                is_new_point: typing.Union[bool, typing.Any] = False):
+                slide_feather: bool = False,
+                is_new_point: bool = False):
     ''' Slide control points
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param slide_feather: Slide Feather, First try to slide feather instead of vertex
-    :type slide_feather: typing.Union[bool, typing.Any]
+    :type slide_feather: bool
     :param is_new_point: Slide New Point, Newly created vertex is being slid
-    :type is_new_point: typing.Union[bool, typing.Any]
+    :type is_new_point: bool
     '''
 
     pass
@@ -679,12 +695,12 @@ def slide_point(override_context: typing.
 def slide_spline_curvature(override_context: typing.
                            Union[typing.Dict, 'bpy.types.Context'] = None,
                            execution_context: typing.Union[str, int] = None,
-                           undo: typing.Optional[bool] = None):
+                           undo: bool = None):
     ''' Slide a point on the spline to define its curvature
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -693,12 +709,12 @@ def slide_spline_curvature(override_context: typing.
 def switch_direction(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: typing.Optional[bool] = None):
+                     undo: bool = None):
     ''' Switch direction of selected splines
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
