@@ -8,12 +8,12 @@ GenericType = typing.TypeVar("GenericType")
 def copy(override_context: typing.Union[typing.
                                         Dict, 'bpy.types.Context'] = None,
          execution_context: typing.Union[str, int] = None,
-         undo: typing.Optional[bool] = None):
+         undo: bool = None):
     ''' Copy the material settings and nodes
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -22,12 +22,12 @@ def copy(override_context: typing.Union[typing.
 def new(override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None):
+        undo: bool = None):
     ''' Add a new material
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -36,12 +36,12 @@ def new(override_context: typing.Union[typing.
 def paste(override_context: typing.Union[typing.
                                          Dict, 'bpy.types.Context'] = None,
           execution_context: typing.Union[str, int] = None,
-          undo: typing.Optional[bool] = None):
+          undo: bool = None):
     ''' Paste the material settings and nodes
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
