@@ -1,17 +1,27 @@
 import sys
 import typing
 import bpy.types
+import mathutils
+
+GenericType = typing.TypeVar("GenericType")
 
 
-def brush_stroke(stroke: typing.Union[
-        typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
-        List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection'] = None,
+def brush_stroke(override_context: typing.
+                 Union[typing.Dict, 'bpy.types.Context'] = None,
+                 execution_context: typing.Union[str, int] = None,
+                 undo: bool = None,
+                 *,
+                 stroke: bpy.types.
+                 bpy_prop_collection['bpy.types.OperatorStrokeElement'] = None,
                  mode: typing.Union[str, int] = 'NORMAL',
                  ignore_background_click: bool = False):
     ''' Sculpt a stroke into the geometry
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param stroke: Stroke
-    :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
+    :type stroke: bpy.types.bpy_prop_collection['bpy.types.OperatorStrokeElement']
     :param mode: Stroke Mode, Action taken when a paint stroke is made * NORMAL Regular -- Apply brush normally. * INVERT Invert -- Invert action of brush for duration of stroke. * SMOOTH Smooth -- Switch brush to smooth mode for duration of stroke.
     :type mode: typing.Union[str, int]
     :param ignore_background_click: Ignore Background Click, Clicks on the background do not start the stroke
@@ -21,7 +31,12 @@ def brush_stroke(stroke: typing.Union[
     pass
 
 
-def cloth_filter(type: typing.Union[str, int] = 'GRAVITY',
+def cloth_filter(override_context: typing.
+                 Union[typing.Dict, 'bpy.types.Context'] = None,
+                 execution_context: typing.Union[str, int] = None,
+                 undo: bool = None,
+                 *,
+                 type: typing.Union[str, int] = 'GRAVITY',
                  strength: float = 1.0,
                  force_axis: typing.Union[typing.Set[str], typing.Set[int]] = {
                      'X', 'Y', 'Z'
@@ -33,6 +48,9 @@ def cloth_filter(type: typing.Union[str, int] = 'GRAVITY',
                  use_collisions: bool = False):
     ''' Applies a cloth simulation deformation to the entire mesh
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param type: Filter Type, Operation that is going to be applied to the mesh * GRAVITY Gravity -- Applies gravity to the simulation. * INFLATE Inflate -- Inflates the cloth. * EXPAND Expand -- Expands the cloth's dimensions. * PINCH Pinch -- Pulls the cloth to the cursor's start position. * SCALE Scale -- Scales the mesh as a soft body using the origin of the object as scale.
     :type type: typing.Union[str, int]
     :param strength: Strength, Filter strength
@@ -54,33 +72,59 @@ def cloth_filter(type: typing.Union[str, int] = 'GRAVITY',
     pass
 
 
-def color_filter(type: typing.Union[str, int] = 'HUE',
-                 strength: float = 1.0,
-                 fill_color: typing.List[float] = (0.0, 0.0, 0.0)):
-    ''' Applies a filter to modify the current sculpt vertex colors
+def color_filter(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        type: typing.Union[str, int] = 'HUE',
+        strength: float = 1.0,
+        fill_color: typing.
+        Union[typing.List[float], typing.
+              Tuple[float, float, float], 'mathutils.Vector'] = (0.0, 0.0,
+                                                                 0.0)):
+    ''' Applies a filter to modify the active color attribute
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param type: Filter Type * FILL Fill -- Fill with a specific color. * HUE Hue -- Change hue. * SATURATION Saturation -- Change saturation. * VALUE Value -- Change value. * BRIGHTNESS Brightness -- Change brightness. * CONTRAST Contrast -- Change contrast. * SMOOTH Smooth -- Smooth colors. * RED Red -- Change red channel. * GREEN Green -- Change green channel. * BLUE Blue -- Change blue channel.
     :type type: typing.Union[str, int]
     :param strength: Strength, Filter strength
     :type strength: float
     :param fill_color: Fill Color
-    :type fill_color: typing.List[float]
+    :type fill_color: typing.Union[typing.List[float], typing.Tuple[float, float, float], 'mathutils.Vector']
     '''
 
     pass
 
 
-def detail_flood_fill():
+def detail_flood_fill(override_context: typing.
+                      Union[typing.Dict, 'bpy.types.Context'] = None,
+                      execution_context: typing.Union[str, int] = None,
+                      undo: bool = None):
     ''' Flood fill the mesh with the selected detail setting
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
 
 
-def dirty_mask(dirty_only: bool = False):
+def dirty_mask(override_context: typing.
+               Union[typing.Dict, 'bpy.types.Context'] = None,
+               execution_context: typing.Union[str, int] = None,
+               undo: bool = None,
+               *,
+               dirty_only: bool = False):
     ''' Generates a mask based on the geometry cavity and pointiness
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param dirty_only: Dirty Only, Don't calculate cleans for convex areas
     :type dirty_only: bool
     '''
@@ -88,23 +132,40 @@ def dirty_mask(dirty_only: bool = False):
     pass
 
 
-def dynamic_topology_toggle():
+def dynamic_topology_toggle(override_context: typing.
+                            Union[typing.Dict, 'bpy.types.Context'] = None,
+                            execution_context: typing.Union[str, int] = None,
+                            undo: bool = None):
     ''' Dynamic topology alters the mesh topology while sculpting
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
 
 
-def dyntopo_detail_size_edit():
+def dyntopo_detail_size_edit(override_context: typing.
+                             Union[typing.Dict, 'bpy.types.Context'] = None,
+                             execution_context: typing.Union[str, int] = None,
+                             undo: bool = None):
     ''' Modify the detail size of dyntopo interactively
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
 
 
-def expand(target: typing.Union[str, int] = 'MASK',
+def expand(override_context: typing.Union[typing.
+                                          Dict, 'bpy.types.Context'] = None,
+           execution_context: typing.Union[str, int] = None,
+           undo: bool = None,
+           *,
+           target: typing.Union[str, int] = 'MASK',
            falloff_type: typing.Union[str, int] = 'GEODESIC',
            invert: bool = False,
            use_mask_preserve: bool = False,
@@ -114,6 +175,9 @@ def expand(target: typing.Union[str, int] = 'MASK',
            max_geodesic_move_preview: int = 10000):
     ''' Generic sculpt expand operator
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param target: Data Target, Data that is going to be modified in the expand operation
     :type target: typing.Union[str, int]
     :param falloff_type: Falloff Type, Initial falloff of the expand operation
@@ -135,7 +199,12 @@ def expand(target: typing.Union[str, int] = 'MASK',
     pass
 
 
-def face_set_box_gesture(xmin: int = 0,
+def face_set_box_gesture(override_context: typing.
+                         Union[typing.Dict, 'bpy.types.Context'] = None,
+                         execution_context: typing.Union[str, int] = None,
+                         undo: bool = None,
+                         *,
+                         xmin: int = 0,
                          xmax: int = 0,
                          ymin: int = 0,
                          ymax: int = 0,
@@ -144,6 +213,9 @@ def face_set_box_gesture(xmin: int = 0,
                          use_limit_to_segment: bool = False):
     ''' Add face set within the box as you move the brush
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param xmin: X Min
     :type xmin: int
     :param xmax: X Max
@@ -163,9 +235,18 @@ def face_set_box_gesture(xmin: int = 0,
     pass
 
 
-def face_set_change_visibility(mode: typing.Union[str, int] = 'TOGGLE'):
+def face_set_change_visibility(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        mode: typing.Union[str, int] = 'TOGGLE'):
     ''' Change the visibility of the Face Sets of the sculpt
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param mode: Mode * TOGGLE Toggle Visibility -- Hide all Face Sets except for the active one. * SHOW_ACTIVE Show Active Face Set -- Show Active Face Set. * HIDE_ACTIVE Hide Active Face Sets -- Hide Active Face Sets. * INVERT Invert Face Set Visibility -- Invert Face Set Visibility. * SHOW_ALL Show All Face Sets -- Show All Face Sets.
     :type mode: typing.Union[str, int]
     '''
@@ -173,10 +254,18 @@ def face_set_change_visibility(mode: typing.Union[str, int] = 'TOGGLE'):
     pass
 
 
-def face_set_edit(mode: typing.Union[str, int] = 'GROW',
+def face_set_edit(override_context: typing.
+                  Union[typing.Dict, 'bpy.types.Context'] = None,
+                  execution_context: typing.Union[str, int] = None,
+                  undo: bool = None,
+                  *,
+                  mode: typing.Union[str, int] = 'GROW',
                   modify_hidden: bool = True):
     ''' Edits the current active Face Set
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param mode: Mode * GROW Grow Face Set -- Grows the Face Sets boundary by one face based on mesh topology. * SHRINK Shrink Face Set -- Shrinks the Face Sets boundary by one face based on mesh topology. * DELETE_GEOMETRY Delete Geometry -- Deletes the faces that are assigned to the Face Set. * FAIR_POSITIONS Fair Positions -- Creates a smooth as possible geometry patch from the Face Set minimizing changes in vertex positions. * FAIR_TANGENCY Fair Tangency -- Creates a smooth as possible geometry patch from the Face Set minimizing changes in vertex tangents.
     :type mode: typing.Union[str, int]
     :param modify_hidden: Modify Hidden, Apply the edit operation to hidden Face Sets
@@ -186,15 +275,23 @@ def face_set_edit(mode: typing.Union[str, int] = 'GROW',
     pass
 
 
-def face_set_lasso_gesture(path: typing.Union[
-        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
-        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
-                           use_front_faces_only: bool = False,
-                           use_limit_to_segment: bool = False):
+def face_set_lasso_gesture(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        path: bpy.types.
+        bpy_prop_collection['bpy.types.OperatorMousePath'] = None,
+        use_front_faces_only: bool = False,
+        use_limit_to_segment: bool = False):
     ''' Add face set within the lasso as you move the brush
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param path: Path
-    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: bpy.types.bpy_prop_collection['bpy.types.OperatorMousePath']
     :param use_front_faces_only: Front Faces Only, Affect only faces facing towards the view
     :type use_front_faces_only: bool
     :param use_limit_to_segment: Limit to Segment, Apply the gesture action only to the area that is contained within the segment without extending its effect to the entire line
@@ -204,9 +301,17 @@ def face_set_lasso_gesture(path: typing.Union[
     pass
 
 
-def face_sets_create(mode: typing.Union[str, int] = 'MASKED'):
+def face_sets_create(override_context: typing.
+                     Union[typing.Dict, 'bpy.types.Context'] = None,
+                     execution_context: typing.Union[str, int] = None,
+                     undo: bool = None,
+                     *,
+                     mode: typing.Union[str, int] = 'MASKED'):
     ''' Create a new Face Set
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param mode: Mode * MASKED Face Set from Masked -- Create a new Face Set from the masked faces. * VISIBLE Face Set from Visible -- Create a new Face Set from the visible vertices. * ALL Face Set Full Mesh -- Create an unique Face Set with all faces in the sculpt. * SELECTION Face Set from Edit Mode Selection -- Create an Face Set corresponding to the Edit Mode face selection.
     :type mode: typing.Union[str, int]
     '''
@@ -214,10 +319,18 @@ def face_sets_create(mode: typing.Union[str, int] = 'MASKED'):
     pass
 
 
-def face_sets_init(mode: typing.Union[str, int] = 'LOOSE_PARTS',
+def face_sets_init(override_context: typing.
+                   Union[typing.Dict, 'bpy.types.Context'] = None,
+                   execution_context: typing.Union[str, int] = None,
+                   undo: bool = None,
+                   *,
+                   mode: typing.Union[str, int] = 'LOOSE_PARTS',
                    threshold: float = 0.5):
     ''' Initializes all Face Sets in the mesh
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param mode: Mode * LOOSE_PARTS Face Sets from Loose Parts -- Create a Face Set per loose part in the mesh. * MATERIALS Face Sets from Material Slots -- Create a Face Set per Material Slot. * NORMALS Face Sets from Mesh Normals -- Create Face Sets for Faces that have similar normal. * UV_SEAMS Face Sets from UV Seams -- Create Face Sets using UV Seams as boundaries. * CREASES Face Sets from Edge Creases -- Create Face Sets using Edge Creases as boundaries. * BEVEL_WEIGHT Face Sets from Bevel Weight -- Create Face Sets using Bevel Weights as boundaries. * SHARP_EDGES Face Sets from Sharp Edges -- Create Face Sets using Sharp Edges as boundaries. * FACE_MAPS Face Sets from Face Maps -- Create a Face Set per Face Map. * FACE_SET_BOUNDARIES Face Sets from Face Set Boundaries -- Create a Face Set per isolated Face Set.
     :type mode: typing.Union[str, int]
     :param threshold: Threshold, Minimum value to consider a certain attribute a boundary when creating the Face Sets
@@ -227,28 +340,49 @@ def face_sets_init(mode: typing.Union[str, int] = 'LOOSE_PARTS',
     pass
 
 
-def face_sets_randomize_colors():
+def face_sets_randomize_colors(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None):
     ''' Generates a new set of random colors to render the Face Sets in the viewport
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
 
 
-def loop_to_vertex_colors():
+def loop_to_vertex_colors(override_context: typing.
+                          Union[typing.Dict, 'bpy.types.Context'] = None,
+                          execution_context: typing.Union[str, int] = None,
+                          undo: bool = None):
     ''' Copy the active loop color layer to the vertex color
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
 
 
-def mask_by_color(contiguous: bool = False,
+def mask_by_color(override_context: typing.
+                  Union[typing.Dict, 'bpy.types.Context'] = None,
+                  execution_context: typing.Union[str, int] = None,
+                  undo: bool = None,
+                  *,
+                  contiguous: bool = False,
                   invert: bool = False,
                   preserve_previous_mask: bool = False,
                   threshold: float = 0.35):
-    ''' Creates a mask based on the sculpt vertex colors
+    ''' Creates a mask based on the active color attribute
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param contiguous: Contiguous, Mask only contiguous color areas
     :type contiguous: bool
     :param invert: Invert, Invert the generated mask
@@ -262,7 +396,12 @@ def mask_by_color(contiguous: bool = False,
     pass
 
 
-def mask_expand(invert: bool = True,
+def mask_expand(override_context: typing.
+                Union[typing.Dict, 'bpy.types.Context'] = None,
+                execution_context: typing.Union[str, int] = None,
+                undo: bool = None,
+                *,
+                invert: bool = True,
                 use_cursor: bool = True,
                 update_pivot: bool = True,
                 smooth_iterations: int = 2,
@@ -273,6 +412,9 @@ def mask_expand(invert: bool = True,
                 create_face_set: bool = False):
     ''' Expands a mask from the initial active vertex under the cursor
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param invert: Invert, Invert the new mask
     :type invert: bool
     :param use_cursor: Use Cursor, Expand the mask to the cursor position
@@ -296,11 +438,19 @@ def mask_expand(invert: bool = True,
     pass
 
 
-def mask_filter(filter_type: typing.Union[str, int] = 'SMOOTH',
+def mask_filter(override_context: typing.
+                Union[typing.Dict, 'bpy.types.Context'] = None,
+                execution_context: typing.Union[str, int] = None,
+                undo: bool = None,
+                *,
+                filter_type: typing.Union[str, int] = 'SMOOTH',
                 iterations: int = 1,
-                auto_iteration_count: bool = False):
+                auto_iteration_count: bool = True):
     ''' Applies a filter to modify the current mask
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filter_type: Type, Filter that is going to be applied to the mask * SMOOTH Smooth Mask -- Smooth mask. * SHARPEN Sharpen Mask -- Sharpen mask. * GROW Grow Mask -- Grow mask. * SHRINK Shrink Mask -- Shrink mask. * CONTRAST_INCREASE Increase Contrast -- Increase the contrast of the paint mask. * CONTRAST_DECREASE Decrease Contrast -- Decrease the contrast of the paint mask.
     :type filter_type: typing.Union[str, int]
     :param iterations: Iterations, Number of times that the filter is going to be applied
@@ -312,9 +462,17 @@ def mask_filter(filter_type: typing.Union[str, int] = 'SMOOTH',
     pass
 
 
-def mask_init(mode: typing.Union[str, int] = 'RANDOM_PER_VERTEX'):
+def mask_init(override_context: typing.Union[typing.
+                                             Dict, 'bpy.types.Context'] = None,
+              execution_context: typing.Union[str, int] = None,
+              undo: bool = None,
+              *,
+              mode: typing.Union[str, int] = 'RANDOM_PER_VERTEX'):
     ''' Creates a new mask for the entire mesh
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param mode: Mode
     :type mode: typing.Union[str, int]
     '''
@@ -322,7 +480,12 @@ def mask_init(mode: typing.Union[str, int] = 'RANDOM_PER_VERTEX'):
     pass
 
 
-def mesh_filter(type: typing.Union[str, int] = 'INFLATE',
+def mesh_filter(override_context: typing.
+                Union[typing.Dict, 'bpy.types.Context'] = None,
+                execution_context: typing.Union[str, int] = None,
+                undo: bool = None,
+                *,
+                type: typing.Union[str, int] = 'INFLATE',
                 strength: float = 1.0,
                 deform_axis: typing.Union[typing.Set[str], typing.Set[int]] = {
                     'X', 'Y', 'Z'
@@ -335,6 +498,9 @@ def mesh_filter(type: typing.Union[str, int] = 'INFLATE',
                 sharpen_curvature_smooth_iterations: int = 0):
     ''' Applies a filter to modify the current mesh
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param type: Filter Type, Operation that is going to be applied to the mesh * SMOOTH Smooth -- Smooth mesh. * SCALE Scale -- Scale mesh. * INFLATE Inflate -- Inflate mesh. * SPHERE Sphere -- Morph into sphere. * RANDOM Random -- Randomize vertex positions. * RELAX Relax -- Relax mesh. * RELAX_FACE_SETS Relax Face Sets -- Smooth the edges of all the Face Sets. * SURFACE_SMOOTH Surface Smooth -- Smooth the surface of the mesh, preserving the volume. * SHARPEN Sharpen -- Sharpen the cavities of the mesh. * ENHANCE_DETAILS Enhance Details -- Enhance the high frequency surface detail. * ERASE_DISCPLACEMENT Erase Displacement -- Deletes the displacement of the Multires Modifier.
     :type type: typing.Union[str, int]
     :param strength: Strength, Filter strength
@@ -358,15 +524,26 @@ def mesh_filter(type: typing.Union[str, int] = 'INFLATE',
     pass
 
 
-def optimize():
+def optimize(override_context: typing.Union[typing.
+                                            Dict, 'bpy.types.Context'] = None,
+             execution_context: typing.Union[str, int] = None,
+             undo: bool = None):
     ''' Recalculate the sculpt BVH to improve performance
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
 
 
-def project_line_gesture(xstart: int = 0,
+def project_line_gesture(override_context: typing.
+                         Union[typing.Dict, 'bpy.types.Context'] = None,
+                         execution_context: typing.Union[str, int] = None,
+                         undo: bool = None,
+                         *,
+                         xstart: int = 0,
                          xend: int = 0,
                          ystart: int = 0,
                          yend: int = 0,
@@ -376,6 +553,9 @@ def project_line_gesture(xstart: int = 0,
                          use_limit_to_segment: bool = False):
     ''' Project the geometry onto a plane defined by a line
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param xstart: X Start
     :type xstart: int
     :param xend: X End
@@ -397,18 +577,32 @@ def project_line_gesture(xstart: int = 0,
     pass
 
 
-def sample_color():
+def sample_color(override_context: typing.
+                 Union[typing.Dict, 'bpy.types.Context'] = None,
+                 execution_context: typing.Union[str, int] = None,
+                 undo: bool = None):
     ''' Sample the vertex color of the active vertex
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
 
 
-def sample_detail_size(location: typing.List[int] = (0, 0),
+def sample_detail_size(override_context: typing.
+                       Union[typing.Dict, 'bpy.types.Context'] = None,
+                       execution_context: typing.Union[str, int] = None,
+                       undo: bool = None,
+                       *,
+                       location: typing.List[int] = (0, 0),
                        mode: typing.Union[str, int] = 'DYNTOPO'):
     ''' Sample the mesh detail on clicked point
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param location: Location, Screen coordinates of sampling
     :type location: typing.List[int]
     :param mode: Detail Mode, Target sculpting workflow that is going to use the sampled size * DYNTOPO Dyntopo -- Sample dyntopo detail. * VOXEL Voxel -- Sample mesh voxel size.
@@ -418,35 +612,61 @@ def sample_detail_size(location: typing.List[int] = (0, 0),
     pass
 
 
-def sculptmode_toggle():
+def sculptmode_toggle(override_context: typing.
+                      Union[typing.Dict, 'bpy.types.Context'] = None,
+                      execution_context: typing.Union[str, int] = None,
+                      undo: bool = None):
     ''' Toggle sculpt mode in 3D view
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
 
 
-def set_detail_size():
+def set_detail_size(override_context: typing.
+                    Union[typing.Dict, 'bpy.types.Context'] = None,
+                    execution_context: typing.Union[str, int] = None,
+                    undo: bool = None):
     ''' Set the mesh detail (either relative or constant one, depending on current dyntopo mode)
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
 
 
-def set_persistent_base():
+def set_persistent_base(override_context: typing.
+                        Union[typing.Dict, 'bpy.types.Context'] = None,
+                        execution_context: typing.Union[str, int] = None,
+                        undo: bool = None):
     ''' Reset the copy of the mesh that is being sculpted on
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
 
 
-def set_pivot_position(mode: typing.Union[str, int] = 'UNMASKED',
+def set_pivot_position(override_context: typing.
+                       Union[typing.Dict, 'bpy.types.Context'] = None,
+                       execution_context: typing.Union[str, int] = None,
+                       undo: bool = None,
+                       *,
+                       mode: typing.Union[str, int] = 'UNMASKED',
                        mouse_x: float = 0.0,
                        mouse_y: float = 0.0):
     ''' Sets the sculpt transform pivot position
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param mode: Mode * ORIGIN Origin -- Sets the pivot to the origin of the sculpt. * UNMASKED Unmasked -- Sets the pivot position to the average position of the unmasked vertices. * BORDER Mask Border -- Sets the pivot position to the center of the border of the mask. * ACTIVE Active Vertex -- Sets the pivot position to the active vertex position. * SURFACE Surface -- Sets the pivot position to the surface under the cursor.
     :type mode: typing.Union[str, int]
     :param mouse_x: Mouse Position X, Position of the mouse used for "Surface" mode
@@ -458,9 +678,17 @@ def set_pivot_position(mode: typing.Union[str, int] = 'UNMASKED',
     pass
 
 
-def symmetrize(merge_tolerance: float = 0.001):
+def symmetrize(override_context: typing.
+               Union[typing.Dict, 'bpy.types.Context'] = None,
+               execution_context: typing.Union[str, int] = None,
+               undo: bool = None,
+               *,
+               merge_tolerance: float = 0.001):
     ''' Symmetrize the topology modifications
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param merge_tolerance: Merge Distance, Distance within which symmetrical vertices are merged
     :type merge_tolerance: float
     '''
@@ -468,7 +696,12 @@ def symmetrize(merge_tolerance: float = 0.001):
     pass
 
 
-def trim_box_gesture(xmin: int = 0,
+def trim_box_gesture(override_context: typing.
+                     Union[typing.Dict, 'bpy.types.Context'] = None,
+                     execution_context: typing.Union[str, int] = None,
+                     undo: bool = None,
+                     *,
+                     xmin: int = 0,
                      xmax: int = 0,
                      ymin: int = 0,
                      ymax: int = 0,
@@ -480,6 +713,9 @@ def trim_box_gesture(xmin: int = 0,
                      trim_orientation: typing.Union[str, int] = 'VIEW'):
     ''' Trims the mesh within the box as you move the brush
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param xmin: X Min
     :type xmin: int
     :param xmax: X Max
@@ -505,18 +741,26 @@ def trim_box_gesture(xmin: int = 0,
     pass
 
 
-def trim_lasso_gesture(path: typing.Union[
-        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
-        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
-                       use_front_faces_only: bool = False,
-                       use_limit_to_segment: bool = False,
-                       trim_mode: typing.Union[str, int] = 'DIFFERENCE',
-                       use_cursor_depth: bool = False,
-                       trim_orientation: typing.Union[str, int] = 'VIEW'):
+def trim_lasso_gesture(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        path: bpy.types.
+        bpy_prop_collection['bpy.types.OperatorMousePath'] = None,
+        use_front_faces_only: bool = False,
+        use_limit_to_segment: bool = False,
+        trim_mode: typing.Union[str, int] = 'DIFFERENCE',
+        use_cursor_depth: bool = False,
+        trim_orientation: typing.Union[str, int] = 'VIEW'):
     ''' Trims the mesh within the lasso as you move the brush
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param path: Path
-    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: bpy.types.bpy_prop_collection['bpy.types.OperatorMousePath']
     :param use_front_faces_only: Front Faces Only, Affect only faces facing towards the view
     :type use_front_faces_only: bool
     :param use_limit_to_segment: Limit to Segment, Apply the gesture action only to the area that is contained within the segment without extending its effect to the entire line
@@ -532,9 +776,17 @@ def trim_lasso_gesture(path: typing.Union[
     pass
 
 
-def uv_sculpt_stroke(mode: typing.Union[str, int] = 'NORMAL'):
+def uv_sculpt_stroke(override_context: typing.
+                     Union[typing.Dict, 'bpy.types.Context'] = None,
+                     execution_context: typing.Union[str, int] = None,
+                     undo: bool = None,
+                     *,
+                     mode: typing.Union[str, int] = 'NORMAL'):
     ''' Sculpt UVs using a brush
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param mode: Mode, Stroke Mode * NORMAL Regular -- Apply brush normally. * INVERT Invert -- Invert action of brush for duration of stroke. * RELAX Relax -- Switch brush to relax mode for duration of stroke.
     :type mode: typing.Union[str, int]
     '''
@@ -542,9 +794,15 @@ def uv_sculpt_stroke(mode: typing.Union[str, int] = 'NORMAL'):
     pass
 
 
-def vertex_to_loop_colors():
+def vertex_to_loop_colors(override_context: typing.
+                          Union[typing.Dict, 'bpy.types.Context'] = None,
+                          execution_context: typing.Union[str, int] = None,
+                          undo: bool = None):
     ''' Copy the Sculpt Vertex Color to a regular color layer
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
