@@ -1,11 +1,12 @@
 import sys
 import typing
 import bpy.types
-import bpy.context
 
 from . import previews
 from . import units
 
+GenericType = typing.TypeVar("GenericType")
+
 
 def app_template_paths(*, path: str = None):
     ''' Returns valid application template paths.
@@ -20,7 +21,7 @@ def app_template_paths(*, path: str = None):
 
 def blend_paths(absolute: bool = False,
                 packed: bool = False,
-                local: bool = False) -> list:
+                local: bool = False) -> typing.List[str]:
     ''' Returns a list of paths to external files referenced by the loaded .blend file.
 
     :param absolute: When true the paths returned are made absolute.
@@ -29,7 +30,7 @@ def blend_paths(absolute: bool = False,
     :type packed: bool
     :param local: When true skip linked library paths.
     :type local: bool
-    :rtype: list
+    :rtype: typing.List[str]
     :return: path list.
     '''
 
@@ -112,7 +113,8 @@ def load_scripts(*,
     pass
 
 
-def make_rna_paths(struct_name: str, prop_name: str, enum_name: str) -> tuple:
+def make_rna_paths(struct_name: str, prop_name: str,
+                   enum_name: str) -> typing.Tuple:
     ''' Create RNA "paths" from given names.
 
     :param struct_name: Name of a RNA struct (like e.g. "Scene").
@@ -121,7 +123,7 @@ def make_rna_paths(struct_name: str, prop_name: str, enum_name: str) -> tuple:
     :type prop_name: str
     :param enum_name: Name of a RNA enum identifier.
     :type enum_name: str
-    :rtype: tuple
+    :rtype: typing.Tuple
     :return: A triple of three "RNA paths" (most_complete_path, "struct.prop", "struct.prop:'enum'"). If no enum_name is given, the third element will always be void.
     '''
 
@@ -136,14 +138,14 @@ def manual_map():
     pass
 
 
-def modules_from_path(path: str, loaded_modules: set) -> list:
+def modules_from_path(path: str, loaded_modules: typing.Set) -> typing.List:
     ''' Load all modules in a path and return them as a list.
 
     :param path: this path is scanned for scripts and packages.
     :type path: str
     :param loaded_modules: already loaded module names, files matching these names will be ignored.
-    :type loaded_modules: set
-    :rtype: list
+    :type loaded_modules: typing.Set
+    :rtype: typing.List
     :return: all loaded modules.
     '''
 
@@ -158,12 +160,12 @@ def preset_find(name, preset_path, *, display_name=False, ext='.py'):
     pass
 
 
-def preset_paths(subdir: str) -> list:
+def preset_paths(subdir: str) -> typing.List:
     ''' Returns a list of paths for a specific preset.
 
     :param subdir: preset subdirectory (must not be an absolute path).
     :type subdir: str
-    :rtype: list
+    :rtype: typing.List
     :return: script paths.
     '''
 
@@ -203,15 +205,15 @@ def register_manual_map(manual_hook):
     pass
 
 
-def register_submodule_factory(module_name: str,
-                               submodule_names: list) -> tuple:
+def register_submodule_factory(
+        module_name: str, submodule_names: typing.List[str]) -> typing.Tuple:
     ''' Utility function to create register and unregister functions which simply load submodules, calling their register & unregister functions.
 
     :param module_name: The module name, typically __name__ .
     :type module_name: str
     :param submodule_names: List of submodule names to load and unload.
-    :type submodule_names: list
-    :rtype: tuple
+    :type submodule_names: typing.List[str]
+    :rtype: typing.Tuple
     :return: register and unregister functions.
     '''
 
@@ -220,7 +222,7 @@ def register_submodule_factory(module_name: str,
 
 def register_tool(tool_cls,
                   *,
-                  after: 'bpy.context.collection' = None,
+                  after=None,
                   separator: bool = False,
                   group: bool = False):
     ''' Register a tool in the toolbar.
@@ -230,7 +232,6 @@ def register_tool(tool_cls,
     :param space_type: Space type identifier.
     :type space_type: str
     :param after: Optional identifiers this tool will be added after.
-    :type after: 'bpy.context.collection'
     :param separator: When true, add a separator before this tool.
     :type separator: bool
     :param group: When true, add a new nested group of tools.
@@ -278,7 +279,7 @@ def script_paths(*,
                  subdir: str = None,
                  user_pref: bool = True,
                  check_all: bool = False,
-                 use_user=True) -> list:
+                 use_user=True) -> typing.List:
     ''' Returns a list of valid script paths.
 
     :param subdir: Optional subdir.
@@ -287,7 +288,7 @@ def script_paths(*,
     :type user_pref: bool
     :param check_all: Include local, user and system paths rather just the paths blender uses.
     :type check_all: bool
-    :rtype: list
+    :rtype: typing.List
     :return: script paths.
     '''
 
@@ -306,14 +307,11 @@ def smpte_from_frame(frame: int, *, fps=None, fps_base=None) -> str:
     pass
 
 
-def smpte_from_seconds(time: typing.Union[int, float],
-                       *,
-                       fps=None,
-                       fps_base=None) -> str:
+def smpte_from_seconds(time: int, *, fps=None, fps_base=None) -> str:
     ''' Returns an SMPTE formatted string from the *time*: HH:MM:SS:FF . If *fps* and *fps_base* are not given the current scene is used.
 
     :param time: time in seconds.
-    :type time: typing.Union[int, float]
+    :type time: int
     :rtype: str
     :return: the frame string.
     '''
