@@ -2,6 +2,8 @@ import sys
 import typing
 import bpy.types
 
+GenericType = typing.TypeVar("GenericType")
+
 
 def bake_action(obj: 'bpy.types.Object', *, action: 'bpy.types.Action',
                 frames: int, **kwargs) -> 'bpy.types.Action':
@@ -70,14 +72,12 @@ def bake_action_objects(object_action_pairs, *, frames: int,
     pass
 
 
-def bake_action_objects_iter(
-        object_action_pairs: typing.
-        Union['bpy.types.Sequence', 'bpy.types.Object', 'bpy.types.Action'],
-        **kwargs):
+def bake_action_objects_iter(object_action_pairs: 'bpy.types.Sequence',
+                             **kwargs):
     ''' An coroutine that bakes actions for multiple objects.
 
     :param object_action_pairs: Sequence of object action tuples, action is the destination for the baked data. When None a new action will be created.
-    :type object_action_pairs: typing.Union['bpy.types.Sequence', 'bpy.types.Object', 'bpy.types.Action']
+    :type object_action_pairs: 'bpy.types.Sequence'
     '''
 
     pass
