@@ -1,14 +1,16 @@
 import sys
 import typing
-from . import noise
-from . import geometry
-from . import bvhtree
 from . import kdtree
+from . import noise
 from . import interpolate
+from . import bvhtree
+from . import geometry
+
+GenericType = typing.TypeVar("GenericType")
 
 
 class Color:
-    ''' This object gives access to Colors in Blender. :param rgb: (r, g, b) color values :type rgb: 3d vector
+    ''' This object gives access to Colors in Blender. Most colors returned by Blender APIs are in scene linear color space, as defined by the OpenColorIO configuration. The notable exception is user interface theming colors, which are in sRGB color space. :param rgb: (r, g, b) color values :type rgb: 3d vector
     '''
 
     b: float = None
@@ -29,10 +31,10 @@ class Color:
     :type: float
     '''
 
-    hsv: float = None
+    hsv: typing.Tuple[float] = None
     ''' HSV Values in [0, 1].
 
-    :type: float
+    :type: typing.Tuple[float]
     '''
 
     is_frozen: bool = None
@@ -90,12 +92,192 @@ class Color:
         '''
         pass
 
+    @staticmethod
+    def from_aces_to_scene_linear() -> 'Color':
+        ''' Convert from ACES2065-1 linear to scene linear color space.
+
+        :rtype: 'Color'
+        :return: A color in scene linear color space.
+        '''
+        pass
+
+    @staticmethod
+    def from_rec709_linear_to_scene_linear() -> 'Color':
+        ''' Convert from Rec.709 linear color space to scene linear color space.
+
+        :rtype: 'Color'
+        :return: A color in scene linear color space.
+        '''
+        pass
+
+    @staticmethod
+    def from_scene_linear_to_aces() -> 'Color':
+        ''' Convert from scene linear to ACES2065-1 linear color space.
+
+        :rtype: 'Color'
+        :return: A color in ACES2065-1 linear color space.
+        '''
+        pass
+
+    @staticmethod
+    def from_scene_linear_to_rec709_linear() -> 'Color':
+        ''' Convert from scene linear to Rec.709 linear color space.
+
+        :rtype: 'Color'
+        :return: A color in Rec.709 linear color space.
+        '''
+        pass
+
+    @staticmethod
+    def from_scene_linear_to_srgb() -> 'Color':
+        ''' Convert from scene linear to sRGB color space.
+
+        :rtype: 'Color'
+        :return: A color in sRGB color space.
+        '''
+        pass
+
+    @staticmethod
+    def from_scene_linear_to_xyz_d65() -> 'Color':
+        ''' Convert from scene linear to CIE XYZ (Illuminant D65) color space.
+
+        :rtype: 'Color'
+        :return: A color in XYZ color space.
+        '''
+        pass
+
+    @staticmethod
+    def from_srgb_to_scene_linear() -> 'Color':
+        ''' Convert from sRGB to scene linear color space.
+
+        :rtype: 'Color'
+        :return: A color in scene linear color space.
+        '''
+        pass
+
+    @staticmethod
+    def from_xyz_d65_to_scene_linear() -> 'Color':
+        ''' Convert from CIE XYZ (Illuminant D65) to scene linear color space.
+
+        :rtype: 'Color'
+        :return: A color in scene linear color space.
+        '''
+        pass
+
     def __init__(self, rgb=(0.0, 0.0, 0.0)):
         ''' 
 
         '''
         pass
 
+    def __add__(self, other: 'Color') -> 'Color':
+        ''' 
+
+        :param other: 
+        :type other: 'Color'
+        :rtype: 'Color'
+        '''
+        pass
+
+    def __sub__(self, other: 'Color') -> 'Color':
+        ''' 
+
+        :param other: 
+        :type other: 'Color'
+        :rtype: 'Color'
+        '''
+        pass
+
+    def __mul__(self, other: typing.Union[int, float]) -> 'Color':
+        ''' 
+
+        :param other: 
+        :type other: typing.Union[int, float]
+        :rtype: 'Color'
+        '''
+        pass
+
+    def __truediv__(self, other: typing.Union[int, float]) -> 'Color':
+        ''' 
+
+        :param other: 
+        :type other: typing.Union[int, float]
+        :rtype: 'Color'
+        '''
+        pass
+
+    def __radd__(self, other: 'Color') -> 'Color':
+        ''' 
+
+        :param other: 
+        :type other: 'Color'
+        :rtype: 'Color'
+        '''
+        pass
+
+    def __rsub__(self, other: 'Color') -> 'Color':
+        ''' 
+
+        :param other: 
+        :type other: 'Color'
+        :rtype: 'Color'
+        '''
+        pass
+
+    def __rmul__(self, other: typing.Union[int, float]) -> 'Color':
+        ''' 
+
+        :param other: 
+        :type other: typing.Union[int, float]
+        :rtype: 'Color'
+        '''
+        pass
+
+    def __rtruediv__(self, other: typing.Union[int, float]) -> 'Color':
+        ''' 
+
+        :param other: 
+        :type other: typing.Union[int, float]
+        :rtype: 'Color'
+        '''
+        pass
+
+    def __iadd__(self, other: 'Color') -> 'Color':
+        ''' 
+
+        :param other: 
+        :type other: 'Color'
+        :rtype: 'Color'
+        '''
+        pass
+
+    def __isub__(self, other: 'Color') -> 'Color':
+        ''' 
+
+        :param other: 
+        :type other: 'Color'
+        :rtype: 'Color'
+        '''
+        pass
+
+    def __imul__(self, other: typing.Union[int, float]) -> 'Color':
+        ''' 
+
+        :param other: 
+        :type other: typing.Union[int, float]
+        :rtype: 'Color'
+        '''
+        pass
+
+    def __itruediv__(self, other: typing.Union[int, float]) -> 'Color':
+        ''' 
+
+        :param other: 
+        :type other: typing.Union[int, float]
+        :rtype: 'Color'
+        '''
+        pass
+
 
 class Euler:
     ''' This object gives access to Eulers in Blender. :param angles: Three angles, in radians. :type angles: 3d vector :param order: Optional order of the angles, a permutation of XYZ . :type order: str
@@ -168,11 +350,11 @@ class Euler:
         '''
         pass
 
-    def rotate(self, other: typing.Union['Quaternion', 'Euler', 'Matrix']):
+    def rotate(self, other: 'Euler'):
         ''' Rotates the euler by another mathutils value.
 
         :param other: rotation component of mathutils value
-        :type other: typing.Union['Quaternion', 'Euler', 'Matrix']
+        :type other: 'Euler'
         '''
         pass
 
@@ -306,14 +488,14 @@ class Matrix:
 
     @classmethod
     def LocRotScale(cls, location: 'Vector',
-                    rotation: typing.Union['Quaternion', 'Euler', 'Matrix'],
+                    rotation: typing.Union['Quaternion', 'Euler'],
                     scale: 'Vector') -> 'Matrix':
         ''' Create a matrix combining translation, rotation and scale, acting as the inverse of the decompose() method. Any of the inputs may be replaced with None if not needed.
 
         :param location: The translation component.
         :type location: 'Vector'
         :param rotation: The rotation component.
-        :type rotation: typing.Union['Quaternion', 'Euler', 'Matrix']
+        :type rotation: typing.Union['Quaternion', 'Euler']
         :param scale: The scale component.
         :type scale: 'Vector'
         :rtype: 'Matrix'
@@ -352,7 +534,8 @@ class Matrix:
         pass
 
     @classmethod
-    def Scale(cls, factor: float, size: int, axis: 'Vector') -> 'Matrix':
+    def Scale(cls, factor: float, size: int,
+              axis: typing.Optional['Vector']) -> 'Matrix':
         ''' Create a matrix representing a scaling.
 
         :param factor: The factor of scaling to apply.
@@ -360,7 +543,7 @@ class Matrix:
         :param size: The size of the scale matrix to construct [2, 4].
         :type size: int
         :param axis: Direction to influence scale. (optional).
-        :type axis: 'Vector'
+        :type axis: typing.Optional['Vector']
         :rtype: 'Matrix'
         :return: A new scale matrix.
         '''
@@ -508,11 +691,11 @@ class Matrix:
         '''
         pass
 
-    def rotate(self, other: typing.Union['Quaternion', 'Euler', 'Matrix']):
+    def rotate(self, other: 'Euler'):
         ''' Rotates the matrix by another mathutils value.
 
         :param other: rotation component of mathutils value
-        :type other: typing.Union['Quaternion', 'Euler', 'Matrix']
+        :type other: 'Euler'
         '''
         pass
 
@@ -604,6 +787,96 @@ class Matrix:
         '''
         pass
 
+    def __add__(self, other: 'Matrix') -> 'Matrix':
+        ''' 
+
+        :param other: 
+        :type other: 'Matrix'
+        :rtype: 'Matrix'
+        '''
+        pass
+
+    def __sub__(self, other: 'Matrix') -> 'Matrix':
+        ''' 
+
+        :param other: 
+        :type other: 'Matrix'
+        :rtype: 'Matrix'
+        '''
+        pass
+
+    def __mul__(self, other: typing.Union[int, float]) -> 'Matrix':
+        ''' 
+
+        :param other: 
+        :type other: typing.Union[int, float]
+        :rtype: 'Matrix'
+        '''
+        pass
+
+    def __matmul__(self, other: 'Matrix') -> 'Matrix':
+        ''' 
+
+        :param other: 
+        :type other: 'Matrix'
+        :rtype: 'Matrix'
+        '''
+        pass
+
+    def __radd__(self, other: 'Matrix') -> 'Matrix':
+        ''' 
+
+        :param other: 
+        :type other: 'Matrix'
+        :rtype: 'Matrix'
+        '''
+        pass
+
+    def __rsub__(self, other: 'Matrix') -> 'Matrix':
+        ''' 
+
+        :param other: 
+        :type other: 'Matrix'
+        :rtype: 'Matrix'
+        '''
+        pass
+
+    def __rmul__(self, other: typing.Union[int, float]) -> 'Matrix':
+        ''' 
+
+        :param other: 
+        :type other: typing.Union[int, float]
+        :rtype: 'Matrix'
+        '''
+        pass
+
+    def __rmatmul__(self, other: 'Matrix') -> 'Matrix':
+        ''' 
+
+        :param other: 
+        :type other: 'Matrix'
+        :rtype: 'Matrix'
+        '''
+        pass
+
+    def __imul__(self, other: typing.Union[int, float]) -> 'Matrix':
+        ''' 
+
+        :param other: 
+        :type other: typing.Union[int, float]
+        :rtype: 'Matrix'
+        '''
+        pass
+
+    def __imatmul__(self, other: 'Matrix') -> 'Matrix':
+        ''' 
+
+        :param other: 
+        :type other: 'Matrix'
+        :rtype: 'Matrix'
+        '''
+        pass
+
 
 class Quaternion:
     ''' This object gives access to Quaternions in Blender. :param seq: size 3 or 4 :type seq: Vector :param angle: rotation angle, in radians :type angle: float The constructor takes arguments in various forms: (), *no args* Create an identity quaternion (*wxyz*) Create a quaternion from a (w, x, y, z) vector. (*exponential_map*) Create a quaternion from a 3d exponential map vector. .. seealso:: :meth: to_exponential_map (*axis, angle*) Create a quaternion representing a rotation of *angle* radians over *axis*. .. seealso:: :meth: to_axis_angle
@@ -776,11 +1049,11 @@ class Quaternion:
         '''
         pass
 
-    def rotate(self, other: typing.Union['Quaternion', 'Euler', 'Matrix']):
+    def rotate(self, other: 'Euler'):
         ''' Rotates the quaternion by another mathutils value.
 
         :param other: rotation component of mathutils value
-        :type other: typing.Union['Quaternion', 'Euler', 'Matrix']
+        :type other: 'Euler'
         '''
         pass
 
@@ -808,10 +1081,10 @@ class Quaternion:
         '''
         pass
 
-    def to_axis_angle(self) -> typing.Union[float, 'Vector']:
+    def to_axis_angle(self) -> 'Vector':
         ''' Return the axis, angle representation of the quaternion.
 
-        :rtype: typing.Union[float, 'Vector']
+        :rtype: 'Vector'
         :return: axis, angle.
         '''
         pass
@@ -844,12 +1117,12 @@ class Quaternion:
         '''
         pass
 
-    def to_swing_twist(self, axis) -> typing.Union[float, 'Quaternion']:
+    def to_swing_twist(self, axis) -> 'Quaternion':
         ''' Split the rotation into a swing quaternion with the specified axis fixed at zero, and the remaining twist rotation angle.
 
-        :param axis: 
+        :param axis:  twist axis as a string in ['X', 'Y', 'Z']
         :type axis: 
-        :rtype: typing.Union[float, 'Quaternion']
+        :rtype: 'Quaternion'
         :return: swing, twist angle.
         '''
         pass
@@ -860,6 +1133,99 @@ class Quaternion:
         '''
         pass
 
+    def __add__(self, other: 'Quaternion') -> 'Quaternion':
+        ''' 
+
+        :param other: 
+        :type other: 'Quaternion'
+        :rtype: 'Quaternion'
+        '''
+        pass
+
+    def __sub__(self, other: 'Quaternion') -> 'Quaternion':
+        ''' 
+
+        :param other: 
+        :type other: 'Quaternion'
+        :rtype: 'Quaternion'
+        '''
+        pass
+
+    def __mul__(self,
+                other: typing.Union[int, float, 'Quaternion']) -> 'Quaternion':
+        ''' 
+
+        :param other: 
+        :type other: typing.Union[int, float, 'Quaternion']
+        :rtype: 'Quaternion'
+        '''
+        pass
+
+    def __matmul__(self, other: 'Vector') -> 'Vector':
+        ''' 
+
+        :param other: 
+        :type other: 'Vector'
+        :rtype: 'Vector'
+        '''
+        pass
+
+    def __radd__(self, other: 'Quaternion') -> 'Quaternion':
+        ''' 
+
+        :param other: 
+        :type other: 'Quaternion'
+        :rtype: 'Quaternion'
+        '''
+        pass
+
+    def __rsub__(self, other: 'Quaternion') -> 'Quaternion':
+        ''' 
+
+        :param other: 
+        :type other: 'Quaternion'
+        :rtype: 'Quaternion'
+        '''
+        pass
+
+    def __rmul__(self, other: typing.Union[int, float, 'Quaternion']
+                 ) -> 'Quaternion':
+        ''' 
+
+        :param other: 
+        :type other: typing.Union[int, float, 'Quaternion']
+        :rtype: 'Quaternion'
+        '''
+        pass
+
+    def __rmatmul__(self, other: 'Vector') -> 'Vector':
+        ''' 
+
+        :param other: 
+        :type other: 'Vector'
+        :rtype: 'Vector'
+        '''
+        pass
+
+    def __imul__(self, other: typing.Union[int, float, 'Quaternion']
+                 ) -> 'Quaternion':
+        ''' 
+
+        :param other: 
+        :type other: typing.Union[int, float, 'Quaternion']
+        :rtype: 'Quaternion'
+        '''
+        pass
+
+    def __imatmul__(self, other: 'Vector') -> 'Vector':
+        ''' 
+
+        :param other: 
+        :type other: 'Vector'
+        :rtype: 'Vector'
+        '''
+        pass
+
 
 class Vector:
     ''' This object gives access to Vectors in Blender. :param seq: Components of the vector, must be a sequence of at least two :type seq: sequence of numbers
@@ -2019,12 +2385,12 @@ class Vector:
         '''
         pass
 
-    def cross(self, other: 'Vector') -> typing.Union[float, 'Vector']:
+    def cross(self, other: 'Vector') -> 'Vector':
         ''' Return the cross product of this vector and another.
 
         :param other: The other vector to perform the cross product with.
         :type other: 'Vector'
-        :rtype: typing.Union[float, 'Vector']
+        :rtype: 'Vector'
         :return: The cross product.
         '''
         pass
@@ -2141,11 +2507,11 @@ class Vector:
         pass
 
     @staticmethod
-    def rotate(other: typing.Union['Quaternion', 'Euler', 'Matrix']):
+    def rotate(other: 'Euler'):
         ''' Rotate the vector by a rotation value.
 
         :param other: rotation component of mathutils value
-        :type other: typing.Union['Quaternion', 'Euler', 'Matrix']
+        :type other: 'Euler'
         '''
         pass
 
@@ -2211,12 +2577,12 @@ class Vector:
         '''
         pass
 
-    def to_tuple(self, precision: int = -1) -> tuple:
+    def to_tuple(self, precision: int = -1) -> typing.Tuple:
         ''' Return this vector as a tuple with.
 
         :param precision: The number to round the value to in [-1, 21].
         :type precision: int
-        :rtype: tuple
+        :rtype: typing.Tuple
         :return: the values of the vector rounded by *precision*
         '''
         pass
@@ -2232,3 +2598,138 @@ class Vector:
 
         '''
         pass
+
+    def __add__(self, other: 'Vector') -> 'Vector':
+        ''' 
+
+        :param other: 
+        :type other: 'Vector'
+        :rtype: 'Vector'
+        '''
+        pass
+
+    def __sub__(self, other: 'Vector') -> 'Vector':
+        ''' 
+
+        :param other: 
+        :type other: 'Vector'
+        :rtype: 'Vector'
+        '''
+        pass
+
+    def __mul__(self, other: typing.Union[int, float]) -> 'Vector':
+        ''' 
+
+        :param other: 
+        :type other: typing.Union[int, float]
+        :rtype: 'Vector'
+        '''
+        pass
+
+    def __truediv__(self, other: typing.Union[int, float]) -> 'Vector':
+        ''' 
+
+        :param other: 
+        :type other: typing.Union[int, float]
+        :rtype: 'Vector'
+        '''
+        pass
+
+    def __matmul__(self, other: 'Matrix') -> 'Vector':
+        ''' 
+
+        :param other: 
+        :type other: 'Matrix'
+        :rtype: 'Vector'
+        '''
+        pass
+
+    def __radd__(self, other: 'Vector') -> 'Vector':
+        ''' 
+
+        :param other: 
+        :type other: 'Vector'
+        :rtype: 'Vector'
+        '''
+        pass
+
+    def __rsub__(self, other: 'Vector') -> 'Vector':
+        ''' 
+
+        :param other: 
+        :type other: 'Vector'
+        :rtype: 'Vector'
+        '''
+        pass
+
+    def __rmul__(self, other: typing.Union[int, float]) -> 'Vector':
+        ''' 
+
+        :param other: 
+        :type other: typing.Union[int, float]
+        :rtype: 'Vector'
+        '''
+        pass
+
+    def __rtruediv__(self, other: typing.Union[int, float]) -> 'Vector':
+        ''' 
+
+        :param other: 
+        :type other: typing.Union[int, float]
+        :rtype: 'Vector'
+        '''
+        pass
+
+    def __rmatmul__(self, other: 'Matrix') -> 'Vector':
+        ''' 
+
+        :param other: 
+        :type other: 'Matrix'
+        :rtype: 'Vector'
+        '''
+        pass
+
+    def __iadd__(self, other: 'Vector') -> 'Vector':
+        ''' 
+
+        :param other: 
+        :type other: 'Vector'
+        :rtype: 'Vector'
+        '''
+        pass
+
+    def __isub__(self, other: 'Vector') -> 'Vector':
+        ''' 
+
+        :param other: 
+        :type other: 'Vector'
+        :rtype: 'Vector'
+        '''
+        pass
+
+    def __imul__(self, other: typing.Union[int, float]) -> 'Vector':
+        ''' 
+
+        :param other: 
+        :type other: typing.Union[int, float]
+        :rtype: 'Vector'
+        '''
+        pass
+
+    def __itruediv__(self, other: typing.Union[int, float]) -> 'Vector':
+        ''' 
+
+        :param other: 
+        :type other: typing.Union[int, float]
+        :rtype: 'Vector'
+        '''
+        pass
+
+    def __imatmul__(self, other: 'Matrix') -> 'Vector':
+        ''' 
+
+        :param other: 
+        :type other: 'Matrix'
+        :rtype: 'Vector'
+        '''
+        pass
